@@ -22,7 +22,7 @@ where
 {
     /// Extend the memory backed by this array with the values from `other`.
     ///
-    /// Different from [`ChunkedArray::append`] which adds chunks to this [`ChunkedArray`] `extent`
+    /// Different from [`ChunkedArray::append`] which adds chunks to this [`ChunkedArray`] `extend`
     /// appends the data from `other` to the underlying `PrimitiveArray` and thus may cause a reallocation.
     ///
     /// However if this does not cause a reallocation, the resulting data structure will not have any extra chunks
@@ -157,7 +157,7 @@ impl BooleanChunked {
 
 #[doc(hidden)]
 impl ListChunked {
-    pub fn extend(&mut self, other: &Self) -> Result<()> {
+    pub fn extend(&mut self, other: &Self) -> PolarsResult<()> {
         // TODO! properly implement mutation
         // this is harder because we don't know the inner type of the list
         self.append(other)
