@@ -114,7 +114,11 @@ macro_rules! impl_dyn_series {
             }
 
             #[cfg(feature = "zip_with")]
-            fn zip_with_same_type(&self, mask: &BooleanChunked, other: &Series) -> Result<Series> {
+            fn zip_with_same_type(
+                &self,
+                mask: &BooleanChunked,
+                other: &Series,
+            ) -> PolarsResult<Series> {
                 ChunkZip::zip_with(&self.0, mask, other.as_ref().as_ref())
                     .map(|ca| ca.into_series())
             }
@@ -180,19 +184,19 @@ macro_rules! impl_dyn_series {
             ) -> Series {
                 ZipOuterJoinColumn::zip_outer_join_column(&self.0, right_column, opt_join_tuples)
             }
-            fn subtract(&self, rhs: &Series) -> Result<Series> {
+            fn subtract(&self, rhs: &Series) -> PolarsResult<Series> {
                 NumOpsDispatch::subtract(&self.0, rhs)
             }
-            fn add_to(&self, rhs: &Series) -> Result<Series> {
+            fn add_to(&self, rhs: &Series) -> PolarsResult<Series> {
                 NumOpsDispatch::add_to(&self.0, rhs)
             }
-            fn multiply(&self, rhs: &Series) -> Result<Series> {
+            fn multiply(&self, rhs: &Series) -> PolarsResult<Series> {
                 NumOpsDispatch::multiply(&self.0, rhs)
             }
-            fn divide(&self, rhs: &Series) -> Result<Series> {
+            fn divide(&self, rhs: &Series) -> PolarsResult<Series> {
                 NumOpsDispatch::divide(&self.0, rhs)
             }
-            fn remainder(&self, rhs: &Series) -> Result<Series> {
+            fn remainder(&self, rhs: &Series) -> PolarsResult<Series> {
                 NumOpsDispatch::remainder(&self.0, rhs)
             }
             fn group_tuples(&self, multithreaded: bool, sorted: bool) -> GroupsProxy {
@@ -200,7 +204,7 @@ macro_rules! impl_dyn_series {
             }
 
             #[cfg(feature = "sort_multiple")]
-            fn argsort_multiple(&self, by: &[Series], reverse: &[bool]) -> Result<IdxCa> {
+            fn argsort_multiple(&self, by: &[Series], reverse: &[bool]) -> PolarsResult<IdxCa> {
                 self.0.argsort_multiple(by, reverse)
             }
         }
@@ -221,7 +225,7 @@ macro_rules! impl_dyn_series {
                 &self,
                 _f: &dyn Fn(&Series) -> Series,
                 _options: RollingOptionsFixedWindow,
-            ) -> Result<Series> {
+            ) -> PolarsResult<Series> {
                 ChunkRollApply::rolling_apply(&self.0, _f, _options).map(|ca| ca.into_series())
             }
 
@@ -230,7 +234,7 @@ macro_rules! impl_dyn_series {
                 self.0.interpolate().into_series()
             }
 
-            fn bitand(&self, other: &Series) -> Result<Series> {
+            fn bitand(&self, other: &Series) -> PolarsResult<Series> {
                 let other = if other.len() == 1 {
                     Cow::Owned(other.cast(self.dtype())?)
                 } else {
@@ -240,7 +244,7 @@ macro_rules! impl_dyn_series {
                 Ok(self.0.bitand(&other).into_series())
             }
 
-            fn bitor(&self, other: &Series) -> Result<Series> {
+            fn bitor(&self, other: &Series) -> PolarsResult<Series> {
                 let other = if other.len() == 1 {
                     Cow::Owned(other.cast(self.dtype())?)
                 } else {
@@ -250,7 +254,7 @@ macro_rules! impl_dyn_series {
                 Ok(self.0.bitor(&other).into_series())
             }
 
-            fn bitxor(&self, other: &Series) -> Result<Series> {
+            fn bitxor(&self, other: &Series) -> PolarsResult<Series> {
                 let other = if other.len() == 1 {
                     Cow::Owned(other.cast(self.dtype())?)
                 } else {
@@ -278,7 +282,7 @@ macro_rules! impl_dyn_series {
                 self.0.shrink_to_fit()
             }
 
-            fn append_array(&mut self, other: ArrayRef) -> Result<()> {
+            fn append_array(&mut self, other: ArrayRef) -> PolarsResult<()> {
                 self.0.append_array(other)
             }
 
@@ -286,7 +290,7 @@ macro_rules! impl_dyn_series {
                 return self.0.slice(offset, length).into_series();
             }
 
-            fn append(&mut self, other: &Series) -> Result<()> {
+            fn append(&mut self, other: &Series) -> PolarsResult<()> {
                 if self.0.dtype() == other.dtype() {
                     self.0.append(other.as_ref().as_ref());
                     Ok(())
@@ -297,7 +301,7 @@ macro_rules! impl_dyn_series {
                 }
             }
 
-            fn extend(&mut self, other: &Series) -> Result<()> {
+            fn extend(&mut self, other: &Series) -> PolarsResult<()> {
                 if self.0.dtype() == other.dtype() {
                     self.0.extend(other.as_ref().as_ref());
                     Ok(())
@@ -308,7 +312,7 @@ macro_rules! impl_dyn_series {
                 }
             }
 
-            fn filter(&self, filter: &BooleanChunked) -> Result<Series> {
+            fn filter(&self, filter: &BooleanChunked) -> PolarsResult<Series> {
                 ChunkFilter::filter(&self.0, filter).map(|ca| ca.into_series())
             }
 
@@ -330,7 +334,7 @@ macro_rules! impl_dyn_series {
                 self.0.take_opt_chunked_unchecked(by).into_series()
             }
 
-            fn take(&self, indices: &IdxCa) -> Result<Series> {
+            fn take(&self, indices: &IdxCa) -> PolarsResult<Series> {
                 let indices = if indices.chunks.len() > 1 {
                     Cow::Owned(indices.rechunk())
                 } else {
@@ -339,7 +343,7 @@ macro_rules! impl_dyn_series {
                 Ok(ChunkTake::take(&self.0, (&*indices).into())?.into_series())
             }
 
-            fn take_iter(&self, iter: &mut dyn TakeIterator) -> Result<Series> {
+            fn take_iter(&self, iter: &mut dyn TakeIterator) -> PolarsResult<Series> {
                 Ok(ChunkTake::take(&self.0, iter.into())?.into_series())
             }
 
@@ -351,7 +355,7 @@ macro_rules! impl_dyn_series {
                 ChunkTake::take_unchecked(&self.0, iter.into()).into_series()
             }
 
-            unsafe fn take_unchecked(&self, idx: &IdxCa) -> Result<Series> {
+            unsafe fn take_unchecked(&self, idx: &IdxCa) -> PolarsResult<Series> {
                 let idx = if idx.chunks.len() > 1 {
                     Cow::Owned(idx.rechunk())
                 } else {
@@ -369,7 +373,7 @@ macro_rules! impl_dyn_series {
             }
 
             #[cfg(feature = "take_opt_iter")]
-            fn take_opt_iter(&self, iter: &mut dyn TakeIteratorNulls) -> Result<Series> {
+            fn take_opt_iter(&self, iter: &mut dyn TakeIteratorNulls) -> PolarsResult<Series> {
                 Ok(ChunkTake::take(&self.0, iter.into())?.into_series())
             }
 
@@ -385,7 +389,7 @@ macro_rules! impl_dyn_series {
                 ChunkExpandAtIndex::expand_at_index(&self.0, index, length).into_series()
             }
 
-            fn cast(&self, data_type: &DataType) -> Result<Series> {
+            fn cast(&self, data_type: &DataType) -> PolarsResult<Series> {
                 self.0.cast(data_type)
             }
 
@@ -415,15 +419,15 @@ macro_rules! impl_dyn_series {
                 self.0.has_validity()
             }
 
-            fn unique(&self) -> Result<Series> {
+            fn unique(&self) -> PolarsResult<Series> {
                 ChunkUnique::unique(&self.0).map(|ca| ca.into_series())
             }
 
-            fn n_unique(&self) -> Result<usize> {
+            fn n_unique(&self) -> PolarsResult<usize> {
                 ChunkUnique::n_unique(&self.0)
             }
 
-            fn arg_unique(&self) -> Result<IdxCa> {
+            fn arg_unique(&self) -> PolarsResult<IdxCa> {
                 ChunkUnique::arg_unique(&self.0)
             }
 
@@ -443,11 +447,11 @@ macro_rules! impl_dyn_series {
                 self.0.is_not_null()
             }
 
-            fn is_unique(&self) -> Result<BooleanChunked> {
+            fn is_unique(&self) -> PolarsResult<BooleanChunked> {
                 ChunkUnique::is_unique(&self.0)
             }
 
-            fn is_duplicated(&self) -> Result<BooleanChunked> {
+            fn is_duplicated(&self) -> PolarsResult<BooleanChunked> {
                 ChunkUnique::is_duplicated(&self.0)
             }
 
@@ -455,7 +459,7 @@ macro_rules! impl_dyn_series {
                 ChunkReverse::reverse(&self.0).into_series()
             }
 
-            fn as_single_ptr(&mut self) -> Result<usize> {
+            fn as_single_ptr(&mut self) -> PolarsResult<usize> {
                 self.0.as_single_ptr()
             }
 
@@ -463,7 +467,7 @@ macro_rules! impl_dyn_series {
                 ChunkShift::shift(&self.0, periods).into_series()
             }
 
-            fn fill_null(&self, strategy: FillNullStrategy) -> Result<Series> {
+            fn fill_null(&self, strategy: FillNullStrategy) -> PolarsResult<Series> {
                 ChunkFillNull::fill_null(&self.0, strategy).map(|ca| ca.into_series())
             }
 
@@ -489,7 +493,7 @@ macro_rules! impl_dyn_series {
                 &self,
                 quantile: f64,
                 interpol: QuantileInterpolOptions,
-            ) -> Result<Series> {
+            ) -> PolarsResult<Series> {
                 QuantileAggSeries::quantile_as_series(&self.0, quantile, interpol)
             }
 
@@ -509,7 +513,7 @@ macro_rules! impl_dyn_series {
             }
 
             #[cfg(feature = "is_in")]
-            fn is_in(&self, other: &Series) -> Result<BooleanChunked> {
+            fn is_in(&self, other: &Series) -> PolarsResult<BooleanChunked> {
                 IsIn::is_in(&self.0, other)
             }
             #[cfg(feature = "repeat_by")]
@@ -518,12 +522,12 @@ macro_rules! impl_dyn_series {
             }
 
             #[cfg(feature = "checked_arithmetic")]
-            fn checked_div(&self, rhs: &Series) -> Result<Series> {
+            fn checked_div(&self, rhs: &Series) -> PolarsResult<Series> {
                 self.0.checked_div(rhs)
             }
 
             #[cfg(feature = "is_first")]
-            fn is_first(&self) -> Result<BooleanChunked> {
+            fn is_first(&self) -> PolarsResult<BooleanChunked> {
                 self.0.is_first()
             }
 
@@ -532,7 +536,7 @@ macro_rules! impl_dyn_series {
                 &self.0
             }
             #[cfg(feature = "mode")]
-            fn mode(&self) -> Result<Series> {
+            fn mode(&self) -> PolarsResult<Series> {
                 Ok(self.0.mode()?.into_series())
             }
 
