@@ -55,7 +55,7 @@ where
         IntoGroupsProxy::group_tuples(&self.0, multithreaded, sorted)
     }
     #[cfg(feature = "zip_with")]
-    fn zip_with_same_type(&self, mask: &BooleanChunked, other: &Series) -> Result<Series> {
+    fn zip_with_same_type(&self, mask: &BooleanChunked, other: &Series) -> PolarsResult<Series> {
         self.0
             .zip_with(mask, other.as_ref().as_ref())
             .map(|ca| ca.into_series())
@@ -91,7 +91,7 @@ where
         ObjectChunked::chunks(&self.0)
     }
 
-    fn append_array(&mut self, other: ArrayRef) -> Result<()> {
+    fn append_array(&mut self, other: ArrayRef) -> PolarsResult<()> {
         ObjectChunked::append_array(&mut self.0, other)
     }
 
@@ -99,7 +99,7 @@ where
         ObjectChunked::slice(&self.0, offset, length).into_series()
     }
 
-    fn append(&mut self, other: &Series) -> Result<()> {
+    fn append(&mut self, other: &Series) -> PolarsResult<()> {
         if self.dtype() == other.dtype() {
             ObjectChunked::append(&mut self.0, other.as_ref().as_ref());
             Ok(())
@@ -110,11 +110,11 @@ where
         }
     }
 
-    fn extend(&mut self, _other: &Series) -> Result<()> {
+    fn extend(&mut self, _other: &Series) -> PolarsResult<()> {
         panic!("extend not implemented for Object dtypes")
     }
 
-    fn filter(&self, filter: &BooleanChunked) -> Result<Series> {
+    fn filter(&self, filter: &BooleanChunked) -> PolarsResult<Series> {
         ChunkFilter::filter(&self.0, filter).map(|ca| ca.into_series())
     }
 
@@ -128,11 +128,11 @@ where
         self.0.take_opt_chunked_unchecked(by).into_series()
     }
 
-    fn take(&self, indices: &IdxCa) -> Result<Series> {
+    fn take(&self, indices: &IdxCa) -> PolarsResult<Series> {
         Ok(ChunkTake::take(&self.0, indices.into())?.into_series())
     }
 
-    fn take_iter(&self, iter: &mut dyn TakeIterator) -> Result<Series> {
+    fn take_iter(&self, iter: &mut dyn TakeIterator) -> PolarsResult<Series> {
         Ok(ChunkTake::take(&self.0, iter.into())?.into_series())
     }
 
@@ -140,7 +140,7 @@ where
         ChunkTake::take_unchecked(&self.0, iter.into()).into_series()
     }
 
-    unsafe fn take_unchecked(&self, idx: &IdxCa) -> Result<Series> {
+    unsafe fn take_unchecked(&self, idx: &IdxCa) -> PolarsResult<Series> {
         let idx = if idx.chunks.len() > 1 {
             Cow::Owned(idx.rechunk())
         } else {
@@ -154,7 +154,7 @@ where
     }
 
     #[cfg(feature = "take_opt_iter")]
-    fn take_opt_iter(&self, _iter: &mut dyn TakeIteratorNulls) -> Result<Series> {
+    fn take_opt_iter(&self, _iter: &mut dyn TakeIteratorNulls) -> PolarsResult<Series> {
         todo!()
     }
 
@@ -175,7 +175,7 @@ where
         ChunkExpandAtIndex::expand_at_index(&self.0, index, length).into_series()
     }
 
-    fn cast(&self, _data_type: &DataType) -> Result<Series> {
+    fn cast(&self, _data_type: &DataType) -> PolarsResult<Series> {
         Err(PolarsError::InvalidOperation(
             "cannot cast array of type ObjectChunked to arrow datatype".into(),
         ))
@@ -192,15 +192,15 @@ where
         ObjectChunked::has_validity(&self.0)
     }
 
-    fn unique(&self) -> Result<Series> {
+    fn unique(&self) -> PolarsResult<Series> {
         ChunkUnique::unique(&self.0).map(|ca| ca.into_series())
     }
 
-    fn n_unique(&self) -> Result<usize> {
+    fn n_unique(&self) -> PolarsResult<usize> {
         ChunkUnique::n_unique(&self.0)
     }
 
-    fn arg_unique(&self) -> Result<IdxCa> {
+    fn arg_unique(&self) -> PolarsResult<IdxCa> {
         ChunkUnique::arg_unique(&self.0)
     }
 
@@ -212,11 +212,11 @@ where
         ObjectChunked::is_not_null(&self.0)
     }
 
-    fn is_unique(&self) -> Result<BooleanChunked> {
+    fn is_unique(&self) -> PolarsResult<BooleanChunked> {
         ChunkUnique::is_unique(&self.0)
     }
 
-    fn is_duplicated(&self) -> Result<BooleanChunked> {
+    fn is_duplicated(&self) -> PolarsResult<BooleanChunked> {
         ChunkUnique::is_duplicated(&self.0)
     }
 
@@ -228,7 +228,7 @@ where
         ChunkShift::shift(&self.0, periods).into_series()
     }
 
-    fn fill_null(&self, strategy: FillNullStrategy) -> Result<Series> {
+    fn fill_null(&self, strategy: FillNullStrategy) -> PolarsResult<Series> {
         ChunkFillNull::fill_null(&self.0, strategy).map(|ca| ca.into_series())
     }
 
@@ -273,7 +273,7 @@ mod test {
     use super::*;
 
     #[test]
-    fn test_downcast_object() -> Result<()> {
+    fn test_downcast_object() -> PolarsResult<()> {
         impl PolarsObject for i32 {
             fn type_name() -> &'static str {
                 "i32"
