@@ -2,6 +2,9 @@
 mod arg_where;
 #[cfg(feature = "round_series")]
 mod clip;
+#[cfg(feature = "temporal")]
+mod datetime;
+mod dispatch;
 mod fill_null;
 #[cfg(feature = "is_in")]
 mod is_in;
@@ -28,18 +31,23 @@ mod temporal;
 #[cfg(feature = "trigonometry")]
 mod trigonometry;
 
+use std::fmt::{Display, Formatter};
+
 #[cfg(feature = "list")]
 pub(super) use list::ListFunction;
 use polars_core::prelude::*;
-use polars_core::utils::slice_offsets;
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
 
+#[cfg(feature = "temporal")]
+pub(super) use self::datetime::TemporalFunction;
 pub(super) use self::nan::NanFunction;
 #[cfg(feature = "strings")]
-pub(super) use self::strings::StringFunction;
+pub(crate) use self::strings::StringFunction;
 #[cfg(feature = "dtype-struct")]
 pub(super) use self::struct_::StructFunction;
+#[cfg(feature = "trigonometry")]
+pub(super) use self::trigonometry::TrigonometricFunction;
 use super::*;
 
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
@@ -57,6 +65,8 @@ pub enum FunctionExpr {
     SearchSorted,
     #[cfg(feature = "strings")]
     StringExpr(StringFunction),
+    #[cfg(feature = "temporal")]
+    TemporalExpr(TemporalFunction),
     #[cfg(feature = "date_offset")]
     DateOffset(Duration),
     #[cfg(feature = "trigonometry")]
@@ -92,24 +102,69 @@ pub enum FunctionExpr {
         k: usize,
         reverse: bool,
     },
+    Shift(i64),
+    Reverse,
+    IsNull,
+    IsNotNull,
+    Not,
+    IsUnique,
+    IsDuplicated,
 }
 
-#[cfg(feature = "trigonometry")]
-#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
-#[derive(Clone, Copy, PartialEq, Debug, Eq, Hash)]
-pub enum TrigonometricFunction {
-    Sin,
-    Cos,
-    Tan,
-    ArcSin,
-    ArcCos,
-    ArcTan,
-    Sinh,
-    Cosh,
-    Tanh,
-    ArcSinh,
-    ArcCosh,
-    ArcTanh,
+impl Display for FunctionExpr {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        use FunctionExpr::*;
+
+        match self {
+            NullCount => write!(f, "null_count"),
+            Pow => write!(f, "pow"),
+            #[cfg(feature = "row_hash")]
+            Hash(_, _, _, _) => write!(f, "hash"),
+            #[cfg(feature = "is_in")]
+            IsIn => write!(f, "is_in"),
+            #[cfg(feature = "arg_where")]
+            ArgWhere => write!(f, "arg_where"),
+            #[cfg(feature = "search_sorted")]
+            SearchSorted => write!(f, "search_sorted"),
+            #[cfg(feature = "strings")]
+            StringExpr(s) => write!(f, "{}", s),
+            #[cfg(feature = "temporal")]
+            TemporalExpr(fun) => write!(f, "{}", fun),
+            #[cfg(feature = "date_offset")]
+            DateOffset(_) => write!(f, "dt.offset_by"),
+            #[cfg(feature = "trigonometry")]
+            Trigonometry(func) => write!(f, "{}", func),
+            #[cfg(feature = "sign")]
+            Sign => write!(f, "sign"),
+            FillNull { .. } => write!(f, "fill_null"),
+            #[cfg(feature = "is_in")]
+            ListContains => write!(f, "arr.contains"),
+            #[cfg(all(feature = "rolling_window", feature = "moment"))]
+            RollingSkew { .. } => write!(f, "rolling_skew"),
+            ShiftAndFill { .. } => write!(f, "shift_and_fill"),
+            Nan(_) => write!(f, "nan"),
+            #[cfg(feature = "round_series")]
+            Clip { min, max } => match (min, max) {
+                (Some(_), Some(_)) => write!(f, "clip"),
+                (None, Some(_)) => write!(f, "clip_max"),
+                (Some(_), None) => write!(f, "clip_min"),
+                _ => unreachable!(),
+            },
+            #[cfg(feature = "list")]
+            ListExpr(func) => write!(f, "{}", func),
+            #[cfg(feature = "dtype-struct")]
+            StructExpr(func) => write!(f, "{}", func),
+            #[cfg(feature = "top_k")]
+            TopK { .. } => write!(f, "top_k"),
+            Shift(_) => write!(f, "shift"),
+            Reverse => write!(f, "reverse"),
+            Not => write!(f, "is_not"),
+            IsNull => write!(f, "is_null"),
+            IsNotNull => write!(f, "is_not_null"),
+            IsUnique => write!(f, "is_unique"),
+            IsDuplicated => write!(f, "is_duplicated"),
+        }
+    }
 }
 
 macro_rules! wrap {
@@ -131,19 +186,6 @@ macro_rules! map_as_slice {
     }};
 }
 
-// Fn(&Series)
-#[macro_export(super)]
-macro_rules! map_without_args {
-    ($func:path) => {{
-        let f = move |s: &mut [Series]| {
-            let s = &s[0];
-            $func(s)
-        };
-
-        SpecialEq::new(Arc::new(f))
-    }};
-}
-
 // FnOnce(Series)
 // FnOnce(Series, args)
 #[macro_export(super)]
@@ -168,7 +210,17 @@ macro_rules! map_owned {
 }
 
 // Fn(&Series, args)
-macro_rules! map_with_args {
+#[macro_export(super)]
+macro_rules! map {
+    ($func:path) => {{
+        let f = move |s: &mut [Series]| {
+            let s = &s[0];
+            $func(s)
+        };
+
+        SpecialEq::new(Arc::new(f))
+    }};
+
     ($func:path, $($args:expr),*) => {{
         let f = move |s: &mut [Series]| {
             let s = &s[0];
@@ -195,7 +247,7 @@ impl From<FunctionExpr> for SpecialEq<Arc<dyn SeriesUdf>> {
             }
             #[cfg(feature = "row_hash")]
             Hash(k0, k1, k2, k3) => {
-                map_with_args!(row_hash::row_hash, k0, k1, k2, k3)
+                map!(row_hash::row_hash, k0, k1, k2, k3)
             }
             #[cfg(feature = "is_in")]
             IsIn => {
@@ -211,6 +263,8 @@ impl From<FunctionExpr> for SpecialEq<Arc<dyn SeriesUdf>> {
             }
             #[cfg(feature = "strings")]
             StringExpr(s) => s.into(),
+            #[cfg(feature = "temporal")]
+            TemporalExpr(func) => func.into(),
 
             #[cfg(feature = "date_offset")]
             DateOffset(offset) => {
@@ -218,11 +272,11 @@ impl From<FunctionExpr> for SpecialEq<Arc<dyn SeriesUdf>> {
             }
             #[cfg(feature = "trigonometry")]
             Trigonometry(trig_function) => {
-                map_with_args!(trigonometry::apply_trigonometric_function, trig_function)
+                map!(trigonometry::apply_trigonometric_function, trig_function)
             }
             #[cfg(feature = "sign")]
             Sign => {
-                map_without_args!(sign::sign)
+                map!(sign::sign)
             }
             FillNull { super_type } => {
                 map_as_slice!(fill_null::fill_null, &super_type)
@@ -234,7 +288,7 @@ impl From<FunctionExpr> for SpecialEq<Arc<dyn SeriesUdf>> {
             }
             #[cfg(all(feature = "rolling_window", feature = "moment"))]
             RollingSkew { window_size, bias } => {
-                map_with_args!(rolling::rolling_skew, window_size, bias)
+                map!(rolling::rolling_skew, window_size, bias)
             }
             ShiftAndFill { periods } => {
                 map_as_slice!(shift_and_fill::shift_and_fill, periods)
@@ -255,14 +309,21 @@ impl From<FunctionExpr> for SpecialEq<Arc<dyn SeriesUdf>> {
             StructExpr(sf) => {
                 use StructFunction::*;
                 match sf {
-                    FieldByIndex(index) => map_with_args!(struct_::get_by_index, index),
-                    FieldByName(name) => map_with_args!(struct_::get_by_name, name.clone()),
+                    FieldByIndex(index) => map!(struct_::get_by_index, index),
+                    FieldByName(name) => map!(struct_::get_by_name, name.clone()),
                 }
             }
             #[cfg(feature = "top_k")]
             TopK { k, reverse } => {
-                map_with_args!(top_k, k, reverse)
+                map!(top_k, k, reverse)
             }
+            Shift(periods) => map!(dispatch::shift, periods),
+            Reverse => map!(dispatch::reverse),
+            IsNull => map!(dispatch::is_null),
+            IsNotNull => map!(dispatch::is_not_null),
+            Not => map!(dispatch::is_not),
+            IsUnique => map!(dispatch::is_unique),
+            IsDuplicated => map!(dispatch::is_duplicated),
         }
     }
 }
@@ -273,45 +334,69 @@ impl From<StringFunction> for SpecialEq<Arc<dyn SeriesUdf>> {
         use StringFunction::*;
         match func {
             Contains { pat, literal } => {
-                map_with_args!(strings::contains, &pat, literal)
+                map!(strings::contains, &pat, literal)
             }
             EndsWith(sub) => {
-                map_with_args!(strings::ends_with, &sub)
+                map!(strings::ends_with, &sub)
             }
             StartsWith(sub) => {
-                map_with_args!(strings::starts_with, &sub)
+                map!(strings::starts_with, &sub)
             }
             Extract { pat, group_index } => {
-                map_with_args!(strings::extract, &pat, group_index)
+                map!(strings::extract, &pat, group_index)
             }
             ExtractAll(pat) => {
-                map_with_args!(strings::extract_all, &pat)
+                map!(strings::extract_all, &pat)
             }
             CountMatch(pat) => {
-                map_with_args!(strings::count_match, &pat)
+                map!(strings::count_match, &pat)
             }
             #[cfg(feature = "string_justify")]
             Zfill(alignment) => {
-                map_with_args!(strings::zfill, alignment)
+                map!(strings::zfill, alignment)
             }
             #[cfg(feature = "string_justify")]
             LJust { width, fillchar } => {
-                map_with_args!(strings::ljust, width, fillchar)
+                map!(strings::ljust, width, fillchar)
             }
             #[cfg(feature = "string_justify")]
             RJust { width, fillchar } => {
-                map_with_args!(strings::rjust, width, fillchar)
+                map!(strings::rjust, width, fillchar)
             }
             #[cfg(feature = "temporal")]
             Strptime(options) => {
-                map_with_args!(strings::strptime, &options)
+                map!(strings::strptime, &options)
             }
             #[cfg(feature = "concat_str")]
-            Concat(delimiter) => map_with_args!(strings::concat, &delimiter),
+            ConcatVertical(delimiter) => map!(strings::concat, &delimiter),
+            #[cfg(feature = "concat_str")]
+            ConcatHorizontal(delimiter) => map_as_slice!(strings::concat_hor, &delimiter),
             #[cfg(feature = "regex")]
             Replace { all, literal } => map_as_slice!(strings::replace, literal, all),
-            Uppercase => map_without_args!(strings::uppercase),
-            Lowercase => map_without_args!(strings::lowercase),
+            Uppercase => map!(strings::uppercase),
+            Lowercase => map!(strings::lowercase),
+        }
+    }
+}
+
+#[cfg(feature = "temporal")]
+impl From<TemporalFunction> for SpecialEq<Arc<dyn SeriesUdf>> {
+    fn from(func: TemporalFunction) -> Self {
+        use TemporalFunction::*;
+        match func {
+            Year => map!(datetime::year),
+            IsoYear => map!(datetime::iso_year),
+            Month => map!(datetime::month),
+            Quarter => map!(datetime::quarter),
+            Week => map!(datetime::week),
+            WeekDay => map!(datetime::weekday),
+            Day => map!(datetime::day),
+            OrdinalDay => map!(datetime::ordinal_day),
+            Hour => map!(datetime::hour),
+            Minute => map!(datetime::minute),
+            Second => map!(datetime::second),
+            NanoSecond => map!(datetime::nanosecond),
+            TimeStamp(tu) => map!(datetime::timestamp, tu),
         }
     }
 }
