@@ -6,7 +6,7 @@ impl FunctionExpr {
         _input_schema: &Schema,
         _cntxt: Context,
         fields: &[Field],
-    ) -> Result<Field> {
+    ) -> PolarsResult<Field> {
         // set a dtype
         let with_dtype = |dtype: DataType| Ok(Field::new(fields[0].name(), dtype));
 
@@ -100,12 +100,23 @@ impl FunctionExpr {
                     #[cfg(feature = "temporal")]
                     Strptime(options) => with_dtype(options.date_dtype.clone()),
                     #[cfg(feature = "concat_str")]
-                    Concat(_) => with_dtype(DataType::Utf8),
+                    ConcatVertical(_) | ConcatHorizontal(_) => with_dtype(DataType::Utf8),
                     #[cfg(feature = "regex")]
                     Replace { .. } => with_dtype(DataType::Utf8),
                     Uppercase | Lowercase => with_dtype(DataType::Utf8),
                 }
             }
+            #[cfg(feature = "temporal")]
+            TemporalExpr(fun) => {
+                use TemporalFunction::*;
+                let dtype = match fun {
+                    Year | IsoYear => DataType::Int32,
+                    Month | Quarter | Week | WeekDay | Day | OrdinalDay | Hour | Minute
+                    | NanoSecond | Second => DataType::UInt32,
+                    TimeStamp(_) => DataType::Int64,
+                };
+                with_dtype(dtype)
+            }
 
             #[cfg(feature = "date_offset")]
             DateOffset(_) => same_type(),
@@ -131,6 +142,7 @@ impl FunctionExpr {
             }
             #[cfg(feature = "dtype-struct")]
             StructExpr(s) => {
+                use polars_core::utils::slice_offsets;
                 use StructFunction::*;
                 match s {
                     FieldByIndex(index) => {
@@ -146,10 +158,12 @@ impl FunctionExpr {
                             let fld = flds
                                 .iter()
                                 .find(|fld| fld.name() == name.as_ref())
-                                .ok_or_else(|| PolarsError::NotFound(name.as_ref().to_string()))?;
+                                .ok_or_else(|| {
+                                    PolarsError::NotFound(name.as_ref().to_string().into())
+                                })?;
                             Ok(fld.clone())
                         } else {
-                            Err(PolarsError::NotFound(name.as_ref().to_string()))
+                            Err(PolarsError::NotFound(name.as_ref().to_string().into()))
                         }
                     }
                 }
