@@ -15,6 +15,8 @@ use rayon::prelude::*;
 use crate::dsl::function_expr::FunctionExpr;
 #[cfg(feature = "list")]
 use crate::dsl::function_expr::ListFunction;
+#[cfg(feature = "strings")]
+use crate::dsl::function_expr::StringFunction;
 use crate::dsl::*;
 use crate::prelude::*;
 
@@ -224,33 +226,29 @@ pub fn argsort_by<E: AsRef<[Expr]>>(by: E, reverse: &[bool]) -> Expr {
     }
 }
 
-#[cfg(feature = "concat_str")]
+#[cfg(all(feature = "concat_str", feature = "strings"))]
 #[cfg_attr(docsrs, doc(cfg(feature = "concat_str")))]
 /// Horizontally concat string columns in linear time
 pub fn concat_str<E: AsRef<[Expr]>>(s: E, sep: &str) -> Expr {
-    let s = s.as_ref().to_vec();
+    let input = s.as_ref().to_vec();
     let sep = sep.to_string();
-    let function = SpecialEq::new(Arc::new(move |s: &mut [Series]| {
-        polars_core::functions::concat_str(s, &sep).map(|ca| ca.into_series())
-    }) as Arc<dyn SeriesUdf>);
-    Expr::AnonymousFunction {
-        input: s,
-        function,
-        output_type: GetOutput::from_type(DataType::Utf8),
+
+    Expr::Function {
+        input,
+        function: StringFunction::ConcatHorizontal(sep).into(),
         options: FunctionOptions {
             collect_groups: ApplyOptions::ApplyGroups,
             input_wildcard_expansion: true,
             auto_explode: true,
-            fmt_str: "concat_by",
             ..Default::default()
         },
     }
 }
 
-#[cfg(feature = "format_str")]
+#[cfg(all(feature = "concat_str", feature = "strings"))]
 #[cfg_attr(docsrs, doc(cfg(feature = "format_str")))]
 /// Format the results of an array of expressions using a format string
-pub fn format_str<E: AsRef<[Expr]>>(format: &str, args: E) -> Result<Expr> {
+pub fn format_str<E: AsRef<[Expr]>>(format: &str, args: E) -> PolarsResult<Expr> {
     let mut args: std::collections::VecDeque<Expr> = args.as_ref().to_vec().into();
 
     // Parse the format string, and seperate substrings between placeholders
@@ -563,7 +561,11 @@ pub fn duration(args: DurationArgs) -> Expr {
 }
 
 /// Concat multiple
-pub fn concat<L: AsRef<[LazyFrame]>>(inputs: L, rechunk: bool) -> Result<LazyFrame> {
+pub fn concat<L: AsRef<[LazyFrame]>>(
+    inputs: L,
+    rechunk: bool,
+    parallel: bool,
+) -> PolarsResult<LazyFrame> {
     let mut inputs = inputs.as_ref().to_vec();
     let lf = std::mem::take(
         inputs
@@ -580,31 +582,27 @@ pub fn concat<L: AsRef<[LazyFrame]>>(inputs: L, rechunk: bool) -> Result<LazyFra
         let lp = std::mem::take(&mut lf.logical_plan);
         lps.push(lp)
     }
+    let options = UnionOptions {
+        parallel,
+        ..Default::default()
+    };
 
     let lp = LogicalPlan::Union {
         inputs: lps,
-        options: Default::default(),
+        options,
     };
     let mut lf = LazyFrame::from(lp);
     lf.opt_state = opt_state;
 
     if rechunk {
-        Ok(lf.map(
-            |mut df: DataFrame| {
-                df.as_single_chunk_par();
-                Ok(df)
-            },
-            Some(AllowedOptimizations::default()),
-            None,
-            Some("RECHUNK"),
-        ))
+        Ok(lf.map_private(FunctionNode::Rechunk))
     } else {
         Ok(lf)
     }
 }
 
 /// Collect all `LazyFrame` computations.
-pub fn collect_all<I>(lfs: I) -> Result<Vec<DataFrame>>
+pub fn collect_all<I>(lfs: I) -> PolarsResult<Vec<DataFrame>>
 where
     I: IntoParallelIterator<Item = LazyFrame>,
 {
@@ -714,7 +712,7 @@ macro_rules! prepare_binary_function {
 /// Apply a closure on the two columns that are evaluated from `Expr` a and `Expr` b.
 pub fn map_binary<F: 'static>(a: Expr, b: Expr, f: F, output_type: GetOutput) -> Expr
 where
-    F: Fn(Series, Series) -> Result<Series> + Send + Sync,
+    F: Fn(Series, Series) -> PolarsResult<Series> + Send + Sync,
 {
     let function = prepare_binary_function!(f);
     a.map_many(function, &[b], output_type)
@@ -722,7 +720,7 @@ where
 
 pub fn apply_binary<F: 'static>(a: Expr, b: Expr, f: F, output_type: GetOutput) -> Expr
 where
-    F: Fn(Series, Series) -> Result<Series> + Send + Sync,
+    F: Fn(Series, Series) -> PolarsResult<Series> + Send + Sync,
 {
     let function = prepare_binary_function!(f);
     a.apply_many(function, &[b], output_type)
@@ -731,7 +729,7 @@ where
 /// Accumulate over multiple columns horizontally / row wise.
 pub fn fold_exprs<F: 'static, E: AsRef<[Expr]>>(acc: Expr, f: F, exprs: E) -> Expr
 where
-    F: Fn(Series, Series) -> Result<Series> + Send + Sync + Clone,
+    F: Fn(Series, Series) -> PolarsResult<Series> + Send + Sync + Clone,
 {
     let mut exprs = exprs.as_ref().to_vec();
     exprs.push(acc);
