@@ -23,29 +23,25 @@ pub mod string;
 mod struct_;
 
 use std::fmt::Debug;
-use std::{
-    ops::{Add, Div, Mul, Rem, Sub},
-    sync::Arc,
-};
+use std::ops::{Add, Div, Mul, Rem, Sub};
+use std::sync::Arc;
 
 pub use expr::*;
 pub use functions::*;
 pub use options::*;
 use polars_arrow::prelude::QuantileInterpolOptions;
-use polars_core::export::arrow::{array::BooleanArray, bitmap::MutableBitmap};
 use polars_core::prelude::*;
 #[cfg(feature = "diff")]
 use polars_core::series::ops::NullBehavior;
 use polars_core::series::IsSorted;
-use polars_core::utils::{get_supertype, NoNull};
+use polars_core::utils::{try_get_supertype, NoNull};
 use polars_ops::prelude::SeriesOps;
 #[cfg(feature = "rolling_window")]
 use polars_time::series::SeriesOpsTime;
 
-use crate::dsl::function_expr::FunctionExpr;
-use crate::dsl::function_expr::NanFunction;
 #[cfg(feature = "trigonometry")]
 use crate::dsl::function_expr::TrigonometricFunction;
+use crate::dsl::function_expr::{FunctionExpr, NanFunction};
 // reexport the lazy method
 pub use crate::frame::IntoLazy;
 pub use crate::logical_plan::lit;
@@ -276,7 +272,7 @@ impl Expr {
     /// Negate `Expr`
     #[allow(clippy::should_implement_trait)]
     pub fn not(self) -> Expr {
-        Expr::Not(Box::new(self))
+        self.map_private(FunctionExpr::Not)
     }
 
     /// Rename Column.
@@ -287,13 +283,13 @@ impl Expr {
     /// Run is_null operation on `Expr`.
     #[allow(clippy::wrong_self_convention)]
     pub fn is_null(self) -> Self {
-        Expr::IsNull(Box::new(self))
+        self.map_private(FunctionExpr::IsNull)
     }
 
     /// Run is_not_null operation on `Expr`.
     #[allow(clippy::wrong_self_convention)]
     pub fn is_not_null(self) -> Self {
-        Expr::IsNotNull(Box::new(self))
+        self.map_private(FunctionExpr::IsNotNull)
     }
 
     /// Drop null values
@@ -303,7 +299,7 @@ impl Expr {
 
     /// Drop NaN values
     pub fn drop_nans(self) -> Self {
-        self.apply_private(NanFunction::DropNans.into(), "drop_nans")
+        self.apply_private(NanFunction::DropNans.into())
     }
 
     /// Reduce groups to minimal value.
@@ -426,7 +422,7 @@ impl Expr {
             other.into(),
             move |mut a, mut b| {
                 if upcast {
-                    let dtype = get_supertype(a.dtype(), b.dtype())?;
+                    let dtype = try_get_supertype(a.dtype(), b.dtype())?;
                     a = a.cast(&dtype)?;
                     b = b.cast(&dtype)?;
                 }
@@ -584,12 +580,12 @@ impl Expr {
     /// This has time complexity `O(n + k log(n))`.
     #[cfg(feature = "top_k")]
     pub fn top_k(self, k: usize, reverse: bool) -> Self {
-        self.apply_private(FunctionExpr::TopK { k, reverse }, "top_k")
+        self.apply_private(FunctionExpr::TopK { k, reverse })
     }
 
     /// Reverse column
     pub fn reverse(self) -> Self {
-        Expr::Reverse(Box::new(self))
+        self.apply_private(FunctionExpr::Reverse)
     }
 
     /// Apply a function/closure once the logical plan get executed.
@@ -603,7 +599,7 @@ impl Expr {
     /// the correct output_type. If None given the output type of the input expr is used.
     pub fn map<F>(self, function: F, output_type: GetOutput) -> Self
     where
-        F: Fn(Series) -> Result<Series> + 'static + Send + Sync,
+        F: Fn(Series) -> PolarsResult<Series> + 'static + Send + Sync,
     {
         let f = move |s: &mut [Series]| function(std::mem::take(&mut s[0]));
 
@@ -622,7 +618,7 @@ impl Expr {
         }
     }
 
-    fn map_private(self, function_expr: FunctionExpr, fmt_str: &'static str) -> Self {
+    fn map_private(self, function_expr: FunctionExpr) -> Self {
         Expr::Function {
             input: vec![self],
             function: function_expr,
@@ -630,9 +626,9 @@ impl Expr {
                 collect_groups: ApplyOptions::ApplyFlat,
                 input_wildcard_expansion: false,
                 auto_explode: false,
-                fmt_str,
                 cast_to_supertypes: false,
                 allow_rename: false,
+                ..Default::default()
             },
         }
     }
@@ -642,7 +638,7 @@ impl Expr {
     /// See the [`Expr::map`] function for the differences between [`map`](Expr::map) and [`apply`](Expr::apply).
     pub fn map_many<F>(self, function: F, arguments: &[Expr], output_type: GetOutput) -> Self
     where
-        F: Fn(&mut [Series]) -> Result<Series> + 'static + Send + Sync,
+        F: Fn(&mut [Series]) -> PolarsResult<Series> + 'static + Send + Sync,
     {
         let mut input = vec![self];
         input.extend_from_slice(arguments);
@@ -668,7 +664,7 @@ impl Expr {
     ///  * `map_list` should be used when the function expects a list aggregated series.
     pub fn map_list<F>(self, function: F, output_type: GetOutput) -> Self
     where
-        F: Fn(Series) -> Result<Series> + 'static + Send + Sync,
+        F: Fn(Series) -> PolarsResult<Series> + 'static + Send + Sync,
     {
         let f = move |s: &mut [Series]| function(std::mem::take(&mut s[0]));
 
@@ -692,7 +688,7 @@ impl Expr {
         options: FunctionOptions,
     ) -> Self
     where
-        F: Fn(Series) -> Result<Series> + 'static + Send + Sync,
+        F: Fn(Series) -> PolarsResult<Series> + 'static + Send + Sync,
     {
         let f = move |s: &mut [Series]| function(std::mem::take(&mut s[0]));
 
@@ -715,7 +711,7 @@ impl Expr {
     /// * `apply` should be used for operations that work on a group of data. e.g. `sum`, `count`, etc.
     pub fn apply<F>(self, function: F, output_type: GetOutput) -> Self
     where
-        F: Fn(Series) -> Result<Series> + 'static + Send + Sync,
+        F: Fn(Series) -> PolarsResult<Series> + 'static + Send + Sync,
     {
         let f = move |s: &mut [Series]| function(std::mem::take(&mut s[0]));
 
@@ -731,13 +727,12 @@ impl Expr {
         }
     }
 
-    fn apply_private(self, function_expr: FunctionExpr, fmt_str: &'static str) -> Self {
+    fn apply_private(self, function_expr: FunctionExpr) -> Self {
         Expr::Function {
             input: vec![self],
             function: function_expr,
             options: FunctionOptions {
                 collect_groups: ApplyOptions::ApplyGroups,
-                fmt_str,
                 ..Default::default()
             },
         }
@@ -748,7 +743,7 @@ impl Expr {
     /// See the [`Expr::apply`] function for the differences between [`map`](Expr::map) and [`apply`](Expr::apply).
     pub fn apply_many<F>(self, function: F, arguments: &[Expr], output_type: GetOutput) -> Self
     where
-        F: Fn(&mut [Series]) -> Result<Series> + 'static + Send + Sync,
+        F: Fn(&mut [Series]) -> PolarsResult<Series> + 'static + Send + Sync,
     {
         let mut input = vec![self];
         input.extend_from_slice(arguments);
@@ -770,7 +765,6 @@ impl Expr {
         self,
         function_expr: FunctionExpr,
         arguments: &[Expr],
-        fmt_str: &'static str,
         auto_explode: bool,
         cast_to_supertypes: bool,
     ) -> Self {
@@ -784,7 +778,6 @@ impl Expr {
             options: FunctionOptions {
                 collect_groups: ApplyOptions::ApplyGroups,
                 auto_explode,
-                fmt_str,
                 cast_to_supertypes,
                 ..Default::default()
             },
@@ -795,7 +788,6 @@ impl Expr {
         self,
         function_expr: FunctionExpr,
         arguments: &[Expr],
-        fmt_str: &'static str,
         cast_to_supertypes: bool,
     ) -> Self {
         let mut input = Vec::with_capacity(arguments.len() + 1);
@@ -808,7 +800,6 @@ impl Expr {
             options: FunctionOptions {
                 collect_groups: ApplyOptions::ApplyFlat,
                 auto_explode: true,
-                fmt_str,
                 cast_to_supertypes,
                 ..Default::default()
             },
@@ -837,20 +828,17 @@ impl Expr {
 
     /// Get mask of NaN values if dtype is Float
     pub fn is_nan(self) -> Self {
-        self.map_private(NanFunction::IsNan.into(), "is_nan")
+        self.map_private(NanFunction::IsNan.into())
     }
 
     /// Get inverse mask of NaN values if dtype is Float
     pub fn is_not_nan(self) -> Self {
-        self.map_private(NanFunction::IsNotNan.into(), "is_not_nan")
+        self.map_private(NanFunction::IsNotNan.into())
     }
 
     /// Shift the values in the array by some period. See [the eager implementation](polars_core::series::SeriesTrait::shift).
     pub fn shift(self, periods: i64) -> Self {
-        Expr::Shift {
-            input: Box::new(self),
-            periods,
-        }
+        self.apply_private(FunctionExpr::Shift(periods))
     }
 
     /// Shift the values in the array by some period and fill the resulting empty values.
@@ -858,7 +846,6 @@ impl Expr {
         self.apply_many_private(
             FunctionExpr::ShiftAndFill { periods },
             &[fill_value.into()],
-            "shift_and_fill",
             false,
             true,
         )
@@ -988,39 +975,30 @@ impl Expr {
     #[cfg(feature = "round_series")]
     #[cfg_attr(docsrs, doc(cfg(feature = "round_series")))]
     pub fn clip(self, min: AnyValue<'_>, max: AnyValue<'_>) -> Self {
-        self.map_private(
-            FunctionExpr::Clip {
-                min: Some(min.into_static().unwrap()),
-                max: Some(max.into_static().unwrap()),
-            },
-            "clip",
-        )
+        self.map_private(FunctionExpr::Clip {
+            min: Some(min.into_static().unwrap()),
+            max: Some(max.into_static().unwrap()),
+        })
     }
 
     /// Clip underlying values to a set boundary.
     #[cfg(feature = "round_series")]
     #[cfg_attr(docsrs, doc(cfg(feature = "round_series")))]
     pub fn clip_max(self, max: AnyValue<'_>) -> Self {
-        self.map_private(
-            FunctionExpr::Clip {
-                min: None,
-                max: Some(max.into_static().unwrap()),
-            },
-            "clip_max",
-        )
+        self.map_private(FunctionExpr::Clip {
+            min: None,
+            max: Some(max.into_static().unwrap()),
+        })
     }
 
     /// Clip underlying values to a set boundary.
     #[cfg(feature = "round_series")]
     #[cfg_attr(docsrs, doc(cfg(feature = "round_series")))]
     pub fn clip_min(self, min: AnyValue<'_>) -> Self {
-        self.map_private(
-            FunctionExpr::Clip {
-                min: Some(min.into_static().unwrap()),
-                max: None,
-            },
-            "clip_min",
-        )
+        self.map_private(FunctionExpr::Clip {
+            min: Some(min.into_static().unwrap()),
+            max: None,
+        })
     }
 
     /// Convert all values to their absolute/positive value.
@@ -1042,7 +1020,7 @@ impl Expr {
     /// use polars_core::prelude::*;
     /// use polars_lazy::prelude::*;
     ///
-    /// fn example() -> Result<()> {
+    /// fn example() -> PolarsResult<()> {
     ///     let df = df! {
     ///             "groups" => &[1, 1, 2, 2, 1, 2, 3, 3, 1],
     ///             "values" => &[1, 2, 3, 4, 5, 6, 7, 8, 8]
@@ -1116,7 +1094,6 @@ impl Expr {
             },
             options: FunctionOptions {
                 collect_groups: ApplyOptions::ApplyFlat,
-                fmt_str: "fill_null",
                 cast_to_supertypes: true,
                 ..Default::default()
             },
@@ -1157,13 +1134,13 @@ impl Expr {
     /// Get a mask of duplicated values
     #[allow(clippy::wrong_self_convention)]
     pub fn is_duplicated(self) -> Self {
-        Expr::Duplicated(Box::new(self))
+        self.apply_private(FunctionExpr::IsDuplicated)
     }
 
     /// Get a mask of unique values
     #[allow(clippy::wrong_self_convention)]
     pub fn is_unique(self) -> Self {
-        Expr::IsUnique(Box::new(self))
+        self.apply_private(FunctionExpr::IsUnique)
     }
 
     /// and operation
@@ -1412,9 +1389,9 @@ impl Expr {
         let arguments = &[other];
         // we don't have to apply on groups, so this is faster
         if has_literal {
-            self.map_many_private(FunctionExpr::IsIn, arguments, "is_in_map", true)
+            self.map_many_private(FunctionExpr::IsIn, arguments, true)
         } else {
-            self.apply_many_private(FunctionExpr::IsIn, arguments, "is_in_apply", true, true)
+            self.apply_many_private(FunctionExpr::IsIn, arguments, true, true)
         }
     }
 
@@ -1589,7 +1566,9 @@ impl Expr {
         options: RollingOptions,
         expr_name: &'static str,
         expr_name_by: &'static str,
-        rolling_fn: Arc<dyn (Fn(&Series, RollingOptionsImpl) -> Result<Series>) + Send + Sync>,
+        rolling_fn: Arc<
+            dyn (Fn(&Series, RollingOptionsImpl) -> PolarsResult<Series>) + Send + Sync,
+        >,
     ) -> Expr {
         if let Some(ref by) = options.by {
             self.apply_many(
@@ -1756,10 +1735,7 @@ impl Expr {
     #[cfg(feature = "rolling_window")]
     #[cfg(feature = "moment")]
     pub fn rolling_skew(self, window_size: usize, bias: bool) -> Expr {
-        self.apply_private(
-            FunctionExpr::RollingSkew { window_size, bias },
-            "rolling_skew",
-        )
+        self.apply_private(FunctionExpr::RollingSkew { window_size, bias })
     }
 
     #[cfg_attr(docsrs, doc(cfg(feature = "rolling_window")))]
@@ -2234,7 +2210,7 @@ impl Expr {
     }
     /// Get the null count of the column/group
     pub fn null_count(self) -> Expr {
-        self.apply_private(FunctionExpr::NullCount, "null_count")
+        self.apply_private(FunctionExpr::NullCount)
             .with_function_options(|mut options| {
                 options.auto_explode = true;
                 options
@@ -2259,7 +2235,7 @@ impl Expr {
     #[cfg(feature = "row_hash")]
     /// Compute the hash of every element
     pub fn hash(self, k0: u64, k1: u64, k2: u64, k3: u64) -> Expr {
-        self.map_private(FunctionExpr::Hash(k0, k1, k2, k3), "hash")
+        self.map_private(FunctionExpr::Hash(k0, k1, k2, k3))
     }
 
     #[cfg(feature = "strings")]
@@ -2341,7 +2317,7 @@ impl Rem for Expr {
 /// the correct output_type. If None given the output type of the input expr is used.
 pub fn map_multiple<F, E>(function: F, expr: E, output_type: GetOutput) -> Expr
 where
-    F: Fn(&mut [Series]) -> Result<Series> + 'static + Send + Sync,
+    F: Fn(&mut [Series]) -> PolarsResult<Series> + 'static + Send + Sync,
     E: AsRef<[Expr]>,
 {
     let input = expr.as_ref().to_vec();
@@ -2367,7 +2343,7 @@ where
 ///  * `map_list_mul` should be used when the function expects a list aggregated series.
 pub fn map_list_multiple<F, E>(function: F, expr: E, output_type: GetOutput) -> Expr
 where
-    F: Fn(&mut [Series]) -> Result<Series> + 'static + Send + Sync,
+    F: Fn(&mut [Series]) -> PolarsResult<Series> + 'static + Send + Sync,
     E: AsRef<[Expr]>,
 {
     let input = expr.as_ref().to_vec();
@@ -2396,7 +2372,7 @@ where
 /// * `[apply_mul]` should be used for operations that work on a group of data. e.g. `sum`, `count`, etc.
 pub fn apply_multiple<F, E>(function: F, expr: E, output_type: GetOutput) -> Expr
 where
-    F: Fn(&mut [Series]) -> Result<Series> + 'static + Send + Sync,
+    F: Fn(&mut [Series]) -> PolarsResult<Series> + 'static + Send + Sync,
     E: AsRef<[Expr]>,
 {
     let input = expr.as_ref().to_vec();
