@@ -199,9 +199,9 @@ impl<'a> LazyCsvReader<'a> {
     /// Modify a schema before we run the lazy scanning.
     ///
     /// Important! Run this function latest in the builder!
-    pub fn with_schema_modify<F>(self, f: F) -> Result<Self>
+    pub fn with_schema_modify<F>(self, f: F) -> PolarsResult<Self>
     where
-        F: Fn(Schema) -> Result<Schema>,
+        F: Fn(Schema) -> PolarsResult<Schema>,
     {
         let mut file = std::fs::File::open(&self.path)?;
         let reader_bytes = get_reader_bytes(&mut file).expect("could not mmap file");
@@ -234,7 +234,7 @@ impl<'a> LazyCsvReader<'a> {
         Ok(self.with_schema(Arc::new(schema)))
     }
 
-    pub fn finish_impl(self) -> Result<LazyFrame> {
+    pub fn finish_impl(self) -> PolarsResult<LazyFrame> {
         let mut lf: LazyFrame = LogicalPlanBuilder::scan_csv(
             self.path,
             self.delimiter,
@@ -263,7 +263,7 @@ impl<'a> LazyCsvReader<'a> {
         Ok(lf)
     }
 
-    pub fn finish(self) -> Result<LazyFrame> {
+    pub fn finish(self) -> PolarsResult<LazyFrame> {
         let path_str = self.path.to_string_lossy();
         if path_str.contains('*') {
             let paths = glob::glob(&path_str)
@@ -282,12 +282,16 @@ impl<'a> LazyCsvReader<'a> {
                     builder.rechunk = false;
                     builder.finish_impl()
                 })
-                .collect::<Result<Vec<_>>>()?;
-            concat(&lfs, self.rechunk)
+                .collect::<PolarsResult<Vec<_>>>()?;
+            // set to false, as the csv parser has full thread utilization
+            concat(&lfs, self.rechunk, false)
                 .map_err(|_| PolarsError::ComputeError("no matching files found".into()))
                 .map(|lf| {
                     if self.skip_rows != 0 || self.n_rows.is_some() {
-                        lf.slice(self.skip_rows as i64, self.n_rows.unwrap() as IdxSize)
+                        lf.slice(
+                            self.skip_rows as i64,
+                            self.n_rows.unwrap_or(usize::MAX) as IdxSize,
+                        )
                     } else {
                         lf
                     }
