@@ -26,7 +26,10 @@ use crate::prelude::*;
 use crate::utils;
 use crate::utils::{combine_predicates_expr, has_expr};
 
-pub(crate) fn prepare_projection(exprs: Vec<Expr>, schema: &Schema) -> Result<(Vec<Expr>, Schema)> {
+pub(crate) fn prepare_projection(
+    exprs: Vec<Expr>,
+    schema: &Schema,
+) -> PolarsResult<(Vec<Expr>, Schema)> {
     let exprs = rewrite_projections(exprs, schema, &[]);
     let schema = utils::expressions_to_schema(&exprs, schema, Context::Default)?;
     Ok((exprs, schema))
@@ -63,7 +66,7 @@ impl LogicalPlanBuilder {
         skip_rows: Option<usize>,
         n_rows: Option<usize>,
         name: &'static str,
-    ) -> Result<Self> {
+    ) -> PolarsResult<Self> {
         let schema = Arc::new(match schema {
             Some(s) => s,
             None => function.schema(infer_schema_length)?,
@@ -96,7 +99,7 @@ impl LogicalPlanBuilder {
         row_count: Option<RowCount>,
         rechunk: bool,
         low_memory: bool,
-    ) -> Result<Self> {
+    ) -> PolarsResult<Self> {
         use polars_io::SerReader as _;
 
         let path = path.into();
@@ -124,7 +127,7 @@ impl LogicalPlanBuilder {
 
     #[cfg(feature = "ipc")]
     #[cfg_attr(docsrs, doc(cfg(feature = "ipc")))]
-    pub fn scan_ipc<P: Into<PathBuf>>(path: P, options: IpcScanOptions) -> Result<Self> {
+    pub fn scan_ipc<P: Into<PathBuf>>(path: P, options: IpcScanOptions) -> PolarsResult<Self> {
         use polars_io::SerReader as _;
 
         let path = path.into();
@@ -164,7 +167,7 @@ impl LogicalPlanBuilder {
         encoding: CsvEncoding,
         row_count: Option<RowCount>,
         parse_dates: bool,
-    ) -> Result<Self> {
+    ) -> PolarsResult<Self> {
         let path = path.into();
         let mut file = std::fs::File::open(&path)?;
         let mut magic_nr = [0u8; 2];
@@ -229,7 +232,12 @@ impl LogicalPlanBuilder {
     pub fn cache(self) -> Self {
         let input = Box::new(self.0);
         let id = input.as_ref() as *const LogicalPlan as usize;
-        LogicalPlan::Cache { input, id }.into()
+        LogicalPlan::Cache {
+            input,
+            id,
+            count: usize::MAX,
+        }
+        .into()
     }
 
     pub fn project(self, exprs: Vec<Expr>) -> Self {
@@ -299,9 +307,13 @@ impl LogicalPlanBuilder {
         let mut new_schema = (**schema).clone();
         let (exprs, _) = try_delayed!(prepare_projection(exprs, &schema), &self.0, into);
 
+        let mut arena = Arena::with_capacity(8);
         for e in &exprs {
-            let field = e.to_field(&schema, Context::Default).unwrap();
+            let field = e
+                .to_field_amortized(&schema, Context::Default, &mut arena)
+                .unwrap();
             new_schema.with_column(field.name().to_string(), field.data_type().clone());
+            arena.clear();
         }
 
         LogicalPlan::HStack {
@@ -392,7 +404,7 @@ impl LogicalPlanBuilder {
             let dtype = try_delayed!(
                 current_schema
                     .get(name)
-                    .ok_or_else(|| PolarsError::NotFound(name.clone())),
+                    .ok_or_else(|| PolarsError::NotFound(name.to_string().into())),
                 self.0,
                 into
             );
@@ -424,6 +436,7 @@ impl LogicalPlanBuilder {
         LogicalPlan::DataFrameScan {
             df: Arc::new(df),
             schema,
+            output_schema: None,
             projection: None,
             selection: None,
         }
@@ -512,13 +525,18 @@ impl LogicalPlanBuilder {
     ) -> Self {
         let schema_left = try_delayed!(self.0.schema(), &self.0, into);
         let schema_right = try_delayed!(other.schema(), &self.0, into);
+        let mut arena = Arena::with_capacity(8);
         let right_names = try_delayed!(
             right_on
                 .iter()
-                .map(|e| e
-                    .to_field(&schema_right, Context::Default)
-                    .map(|field| field.name))
-                .collect::<Result<Vec<_>>>(),
+                .map(|e| {
+                    let name = e
+                        .to_field_amortized(&schema_right, Context::Default, &mut arena)
+                        .map(|field| field.name);
+                    arena.clear();
+                    name
+                })
+                .collect::<PolarsResult<Vec<_>>>(),
             &self.0,
             into
         );
@@ -545,6 +563,14 @@ impl LogicalPlanBuilder {
         }
         .into()
     }
+    pub(crate) fn map_private(self, function: FunctionNode) -> Self {
+        LogicalPlan::MapFunction {
+            input: Box::new(self.0),
+            function,
+        }
+        .into()
+    }
+
     pub fn map<F>(
         self,
         function: F,
