@@ -5,7 +5,7 @@ use crate::logical_plan::functions::FunctionNode;
 use crate::logical_plan::iterator::*;
 use crate::prelude::stack_opt::OptimizationRule;
 use crate::prelude::*;
-use crate::utils::aexpr_to_root_names;
+use crate::utils::aexpr_to_leaf_names;
 
 /// If we realize that a predicate drops nulls on a subset
 /// we replace it with an explicit df.drop_nulls call, as this
@@ -74,7 +74,7 @@ impl OptimizationRule for ReplaceDropNulls {
                 }
                 if not_null_count == column_count && binary_and_count < column_count {
                     let subset = Arc::new(
-                        aexpr_to_root_names(*predicate, expr_arena)
+                        aexpr_to_leaf_names(*predicate, expr_arena)
                             .iter()
                             .map(|s| s.to_string())
                             .collect::<Vec<_>>(),
@@ -103,7 +103,7 @@ mod test {
     use crate::utils::test::optimize_lp;
 
     #[test]
-    fn test_drop_nulls_optimization() -> Result<()> {
+    fn test_drop_nulls_optimization() -> PolarsResult<()> {
         let mut rules: Vec<Box<dyn OptimizationRule>> = vec![Box::new(ReplaceDropNulls {})];
         let df = fruits_cars();
 
@@ -121,7 +121,7 @@ mod test {
     }
 
     #[test]
-    fn test_filter() -> Result<()> {
+    fn test_filter() -> PolarsResult<()> {
         // This tests if the filter does not accidentally is optimized by ReplaceNulls
 
         let data = vec![
