@@ -4,10 +4,18 @@ use polars_core::prelude::*;
 use crate::prelude::*;
 
 pub(crate) mod aggregate_pushdown;
+pub(crate) mod cache_states;
+#[cfg(feature = "cse")]
+pub(crate) mod cse;
 pub(crate) mod delay_rechunk;
 pub(crate) mod drop_nulls;
 pub(crate) mod fast_projection;
-#[cfg(any(feature = "ipc", feature = "parquet", feature = "csv-file"))]
+#[cfg(any(
+    feature = "ipc",
+    feature = "parquet",
+    feature = "csv-file",
+    feature = "cse"
+))]
 pub(crate) mod file_caching;
 pub(crate) mod predicate_pushdown;
 pub(crate) mod projection_pushdown;
@@ -22,7 +30,7 @@ pub(crate) use slice_pushdown_lp::SlicePushDown;
 use crate::prelude::stack_opt::OptimizationRule;
 
 pub trait Optimize {
-    fn optimize(&self, logical_plan: LogicalPlan) -> Result<LogicalPlan>;
+    fn optimize(&self, logical_plan: LogicalPlan) -> PolarsResult<LogicalPlan>;
 }
 
 // arbitrary constant to reduce reallocation.
