@@ -7,7 +7,7 @@ use utils::*;
 use crate::dsl::function_expr::FunctionExpr;
 use crate::logical_plan::{optimizer, Context};
 use crate::prelude::*;
-use crate::utils::{aexpr_to_root_names, aexprs_to_schema, check_input_node, has_aexpr};
+use crate::utils::{aexpr_to_leaf_names, aexprs_to_schema, check_input_node, has_aexpr};
 
 #[derive(Default)]
 pub(crate) struct PredicatePushDown {}
@@ -36,7 +36,7 @@ impl PredicatePushDown {
         acc_predicates: PlHashMap<Arc<str>, Node>,
         lp_arena: &mut Arena<ALogicalPlan>,
         expr_arena: &mut Arena<AExpr>,
-    ) -> Result<()> {
+    ) -> PolarsResult<()> {
         let alp = lp_arena.take(input);
         let lp = self.push_down(alp, acc_predicates, lp_arena, expr_arena)?;
         lp_arena.replace(input, lp);
@@ -51,7 +51,7 @@ impl PredicatePushDown {
         lp_arena: &mut Arena<ALogicalPlan>,
         expr_arena: &mut Arena<AExpr>,
         has_projections: bool,
-    ) -> Result<ALogicalPlan> {
+    ) -> PolarsResult<ALogicalPlan> {
         let inputs = lp.get_inputs();
         let exprs = lp.get_exprs();
 
@@ -112,7 +112,7 @@ impl PredicatePushDown {
                     lp_arena.replace(node, alp);
                     Ok(node)
                 })
-                .collect::<Result<Vec<_>>>()?;
+                .collect::<PolarsResult<Vec<_>>>()?;
 
             let lp = lp.with_exprs_and_input(exprs, new_inputs);
             Ok(self.optional_apply_predicate(lp, local_predicates, lp_arena, expr_arena))
@@ -126,7 +126,7 @@ impl PredicatePushDown {
         acc_predicates: PlHashMap<Arc<str>, Node>,
         lp_arena: &mut Arena<ALogicalPlan>,
         expr_arena: &mut Arena<AExpr>,
-    ) -> Result<ALogicalPlan> {
+    ) -> PolarsResult<ALogicalPlan> {
         let inputs = lp.get_inputs();
         let exprs = lp.get_exprs();
 
@@ -143,7 +143,7 @@ impl PredicatePushDown {
                 lp_arena.replace(node, alp);
                 Ok(node)
             })
-            .collect::<Result<Vec<_>>>()?;
+            .collect::<PolarsResult<Vec<_>>>()?;
         let lp = lp.with_exprs_and_input(exprs, new_inputs);
 
         // all predicates are done locally
@@ -168,7 +168,7 @@ impl PredicatePushDown {
         mut acc_predicates: PlHashMap<Arc<str>, Node>,
         lp_arena: &mut Arena<ALogicalPlan>,
         expr_arena: &mut Arena<AExpr>,
-    ) -> Result<ALogicalPlan> {
+    ) -> PolarsResult<ALogicalPlan> {
         use ALogicalPlan::*;
 
         match lp {
@@ -178,7 +178,7 @@ impl PredicatePushDown {
                 // we remove it and apply it locally
                 let local_predicates = transfer_to_local_by_node(&mut acc_predicates, |node| predicate_is_pushdown_boundary(node, expr_arena));
 
-                let name = roots_to_key(&aexpr_to_root_names(predicate, expr_arena));
+                let name = roots_to_key(&aexpr_to_leaf_names(predicate, expr_arena));
                 insert_and_combine_predicate(&mut acc_predicates, name, predicate, expr_arena);
                 let alp = lp_arena.take(input);
                 let new_input = self.push_down(alp, acc_predicates, lp_arena, expr_arena)?;
@@ -193,6 +193,7 @@ impl PredicatePushDown {
             DataFrameScan {
                 df,
                 schema,
+                output_schema,
                 projection,
                 selection,
             } => {
@@ -200,6 +201,7 @@ impl PredicatePushDown {
                 let lp = DataFrameScan {
                     df,
                     schema,
+                    output_schema,
                     projection,
                     selection,
                 };
@@ -529,7 +531,7 @@ impl PredicatePushDown {
                 Ok(self.optional_apply_predicate(lp, local_predicates, lp_arena, expr_arena))
             }
             // Pushed down passed these nodes
-            lp @ Cache { .. } |  lp @ Sort { .. } => {
+            lp @ Sort { .. } => {
                 self.pushdown_and_continue(lp, acc_predicates, lp_arena, expr_arena, false)
             }
             lp @ HStack {..} | lp @ Projection {..} | lp @ ExtContext {..} => {
@@ -538,6 +540,8 @@ impl PredicatePushDown {
             // NOT Pushed down passed these nodes
             // predicates influence slice sizes
             lp @ Slice { .. }
+            // caches will be different
+            | lp @ Cache { .. }
             // dont push down predicates. An aggregation needs all rows
             | lp @ Aggregate {..} => {
                 self.no_pushdown_restart_opt(lp, acc_predicates, lp_arena, expr_arena)
@@ -556,7 +560,7 @@ impl PredicatePushDown {
         logical_plan: ALogicalPlan,
         lp_arena: &mut Arena<ALogicalPlan>,
         expr_arena: &mut Arena<AExpr>,
-    ) -> Result<ALogicalPlan> {
+    ) -> PolarsResult<ALogicalPlan> {
         let acc_predicates = PlHashMap::new();
         self.push_down(logical_plan, acc_predicates, lp_arena, expr_arena)
     }
