@@ -1,6 +1,8 @@
 use polars_core::export::chrono;
 use polars_utils::arena::Arena;
 
+#[cfg(feature = "strings")]
+use crate::dsl::function_expr::StringFunction;
 use crate::logical_plan::optimizer::stack_opt::OptimizationRule;
 use crate::logical_plan::*;
 use crate::prelude::function_expr::FunctionExpr;
@@ -241,7 +243,7 @@ impl OptimizationRule for SimplifyBooleanRule {
                 AExpr::Literal(LiteralValue::Boolean(false))
             ) =>
             {
-                let names = aexpr_to_root_names(*truthy, expr_arena);
+                let names = aexpr_to_leaf_names(*truthy, expr_arena);
                 if names.is_empty() {
                     None
                 } else {
@@ -289,6 +291,140 @@ where
     None
 }
 
+#[cfg(all(feature = "strings", feature = "concat_str"))]
+fn string_addition_to_linear_concat(
+    lp_arena: &Arena<ALogicalPlan>,
+    lp_node: Node,
+    expr_arena: &Arena<AExpr>,
+    left_ae: Node,
+    right_ae: Node,
+    left_aexpr: &AExpr,
+    right_aexpr: &AExpr,
+) -> Option<AExpr> {
+    {
+        let lp = lp_arena.get(lp_node);
+        let input = lp.get_input().unwrap();
+        let schema = lp_arena.get(input).schema(lp_arena);
+
+        let get_type = |ae: &AExpr| ae.get_type(&schema, Context::Default, expr_arena).ok();
+        let addition_type = get_type(left_aexpr)
+            .or_else(|| get_type(right_aexpr))
+            .unwrap();
+
+        if addition_type == DataType::Utf8 {
+            match (left_aexpr, right_aexpr) {
+                // concat + concat
+                (
+                    AExpr::Function {
+                        input: input_left,
+                        function:
+                            ref
+                            fun_l @ FunctionExpr::StringExpr(StringFunction::ConcatHorizontal(sep_l)),
+                        options,
+                    },
+                    AExpr::Function {
+                        input: input_right,
+                        function: FunctionExpr::StringExpr(StringFunction::ConcatHorizontal(sep_r)),
+                        ..
+                    },
+                ) => {
+                    if sep_l.is_empty() && sep_r.is_empty() {
+                        let mut input = Vec::with_capacity(input_left.len() + input_right.len());
+                        input.extend_from_slice(input_left);
+                        input.extend_from_slice(input_right);
+                        Some(AExpr::Function {
+                            input,
+                            function: fun_l.clone(),
+                            options: *options,
+                        })
+                    } else {
+                        None
+                    }
+                }
+                // concat + str
+                (
+                    AExpr::Function {
+                        input,
+                        function:
+                            ref fun @ FunctionExpr::StringExpr(StringFunction::ConcatHorizontal(sep)),
+                        options,
+                    },
+                    _,
+                ) => {
+                    if sep.is_empty() {
+                        let mut input = input.clone();
+                        input.push(right_ae);
+                        Some(AExpr::Function {
+                            input,
+                            function: fun.clone(),
+                            options: *options,
+                        })
+                    } else {
+                        None
+                    }
+                }
+                // str + concat
+                (
+                    _,
+                    AExpr::Function {
+                        input: input_right,
+                        function:
+                            ref fun @ FunctionExpr::StringExpr(StringFunction::ConcatHorizontal(sep)),
+                        options,
+                    },
+                ) => {
+                    if sep.is_empty() {
+                        let mut input = Vec::with_capacity(1 + input_right.len());
+                        input.push(left_ae);
+                        input.extend_from_slice(input_right);
+                        Some(AExpr::Function {
+                            input,
+                            function: fun.clone(),
+                            options: *options,
+                        })
+                    } else {
+                        None
+                    }
+                }
+                _ => Some(AExpr::Function {
+                    input: vec![left_ae, right_ae],
+                    function: StringFunction::ConcatHorizontal("".to_string()).into(),
+                    options: FunctionOptions {
+                        collect_groups: ApplyOptions::ApplyGroups,
+                        input_wildcard_expansion: true,
+                        auto_explode: true,
+                        ..Default::default()
+                    },
+                }),
+            }
+        } else {
+            None
+        }
+    }
+}
+
+#[cfg(all(feature = "strings", feature = "concat_str"))]
+fn is_string_concat(ae: &AExpr) -> bool {
+    matches!(ae, AExpr::Function {
+                function:FunctionExpr::StringExpr(
+                    StringFunction::ConcatHorizontal(sep),
+                ),
+                ..
+            } if sep.is_empty())
+}
+
+#[cfg(all(feature = "strings", feature = "concat_str"))]
+fn get_string_concat_input(node: Node, expr_arena: &Arena<AExpr>) -> Option<&[Node]> {
+    match expr_arena.get(node) {
+        AExpr::Function {
+            input,
+            function: FunctionExpr::StringExpr(StringFunction::ConcatHorizontal(sep)),
+            ..
+        } if sep.is_empty() => Some(input),
+        _ => None,
+    }
+}
+
 pub struct SimplifyExprRule {}
 
 impl OptimizationRule for SimplifyExprRule {
@@ -297,10 +433,11 @@ impl OptimizationRule for SimplifyExprRule {
         &self,
         expr_arena: &mut Arena<AExpr>,
         expr_node: Node,
-        _: &Arena<ALogicalPlan>,
-        _: Node,
+        lp_arena: &Arena<ALogicalPlan>,
+        lp_node: Node,
     ) -> Option<AExpr> {
         let expr = expr_arena.get(expr_node);
+
         match expr {
             // lit(left) + lit(right) => lit(left + right)
             // and null propagation
@@ -310,7 +447,28 @@ impl OptimizationRule for SimplifyExprRule {
 
                 // lit(left) + lit(right) => lit(left + right)
                 let out = match op {
-                    Operator::Plus => eval_binary_same_type!(left_aexpr, +, right_aexpr),
+                    Operator::Plus => match eval_binary_same_type!(left_aexpr, +, right_aexpr) {
+                        Some(new) => Some(new),
+                        None => {
+                            // try to replace addition of string columns with `concat_str`
+                            #[cfg(all(feature = "strings", feature = "concat_str"))]
+                            {
+                                string_addition_to_linear_concat(
+                                    lp_arena,
+                                    lp_node,
+                                    expr_arena,
+                                    *left,
+                                    *right,
+                                    left_aexpr,
+                                    right_aexpr,
+                                )
+                            }
+                            #[cfg(not(all(feature = "strings", feature = "concat_str")))]
+                            {
+                                None
+                            }
+                        }
+                    },
                     Operator::Minus => eval_binary_same_type!(left_aexpr, -, right_aexpr),
                     Operator::Multiply => eval_binary_same_type!(left_aexpr, *, right_aexpr),
                     Operator::Divide => eval_binary_same_type!(left_aexpr, /, right_aexpr),
@@ -453,6 +611,35 @@ impl OptimizationRule for SimplifyExprRule {
                 // faster casts (we only do strict casts)
                 inline_cast(input, data_type)
             }
+            // flatten nested concat_str calls
+            #[cfg(all(feature = "strings", feature = "concat_str"))]
+            AExpr::Function {
+                input,
+                function:
+                    ref function @ FunctionExpr::StringExpr(StringFunction::ConcatHorizontal(sep)),
+                options,
+            } if sep.is_empty() => {
+                if input
+                    .iter()
+                    .any(|node| is_string_concat(expr_arena.get(*node)))
+                {
+                    let mut new_inputs = Vec::with_capacity(input.len() * 2);
+
+                    for node in input {
+                        match get_string_concat_input(*node, expr_arena) {
+                            Some(inp) => new_inputs.extend_from_slice(inp),
+                            None => new_inputs.push(*node),
+                        }
+                    }
+                    Some(AExpr::Function {
+                        input: new_inputs,
+                        function: function.clone(),
+                        options: *options,
+                    })
+                } else {
+                    None
+                }
+            }
 
             _ => None,
         }
