@@ -70,13 +70,12 @@ fn prepare_scan_args<'a>(
 /// Producer of an in memory DataFrame
 pub struct DataFrameExec {
     pub(crate) df: Arc<DataFrame>,
-    pub(crate) projection: Option<Vec<Arc<dyn PhysicalExpr>>>,
     pub(crate) selection: Option<Arc<dyn PhysicalExpr>>,
-    pub(crate) has_windows: bool,
+    pub(crate) projection: Option<Arc<Vec<String>>>,
 }
 
 impl Executor for DataFrameExec {
-    fn execute(&mut self, state: &mut ExecutionState) -> Result<DataFrame> {
+    fn execute(&mut self, state: &mut ExecutionState) -> PolarsResult<DataFrame> {
         let df = mem::take(&mut self.df);
         let mut df = Arc::try_unwrap(df).unwrap_or_else(|df| (*df).clone());
 
@@ -84,7 +83,7 @@ impl Executor for DataFrameExec {
         // TODO: this is only the case if we don't create new columns
         if let Some(projection) = &self.projection {
             state.may_set_schema(&df, projection.len());
-            df = evaluate_physical_expressions(&df, projection, state, self.has_windows)?;
+            df = df.select(projection.as_ref())?;
         }
 
         if let Some(selection) = &self.selection {
@@ -111,7 +110,7 @@ pub(crate) struct AnonymousScanExec {
 }
 
 impl Executor for AnonymousScanExec {
-    fn execute(&mut self, state: &mut ExecutionState) -> Result<DataFrame> {
+    fn execute(&mut self, state: &mut ExecutionState) -> PolarsResult<DataFrame> {
         state.record(
             || {
                 let mut df = self.function.scan(self.options.clone())?;
