@@ -12,7 +12,7 @@ pub(crate) struct UnionExec {
 }
 
 impl Executor for UnionExec {
-    fn execute(&mut self, state: &mut ExecutionState) -> Result<DataFrame> {
+    fn execute(&mut self, state: &mut ExecutionState) -> PolarsResult<DataFrame> {
         #[cfg(debug_assertions)]
         {
             if state.verbose() {
@@ -21,9 +21,15 @@ impl Executor for UnionExec {
         }
         let mut inputs = std::mem::take(&mut self.inputs);
 
-        if self.options.slice && self.options.slice_offset >= 0 {
+        let sliced_path = self.options.slice && self.options.slice_offset >= 0;
+
+        if self.options.parallel || sliced_path {
             if state.verbose() {
-                println!("SLICE AT UNION: union is run sequentially")
+                if self.options.parallel {
+                    println!("UNION: `parallel=false` union is run sequentially")
+                } else {
+                    println!("UNION: `slice is set` union is run sequentially")
+                }
             }
 
             let mut offset = self.options.slice_offset as usize;
@@ -36,6 +42,10 @@ impl Executor for UnionExec {
                     state.branch_idx += idx;
                     let df = input.execute(&mut state)?;
 
+                    if !sliced_path {
+                        return Ok(Some(df));
+                    }
+
                     Ok(if offset > df.height() {
                         offset -= df.height();
                         None
@@ -55,7 +65,7 @@ impl Executor for UnionExec {
                         out
                     })
                 })
-                .collect::<Result<Vec<_>>>()?;
+                .collect::<PolarsResult<Vec<_>>>()?;
 
             concat_df(dfs.iter().flatten())
         } else {
@@ -79,9 +89,9 @@ impl Executor for UnionExec {
                                 state.branch_idx += idx;
                                 input.execute(&mut state)
                             })
-                            .collect::<Result<Vec<_>>>()
+                            .collect::<PolarsResult<Vec<_>>>()
                     })
-                    .collect::<Result<Vec<_>>>()
+                    .collect::<PolarsResult<Vec<_>>>()
             });
 
             concat_df(out?.iter().flat_map(|dfs| dfs.iter()))
