@@ -20,23 +20,23 @@ fn aggregate_expr_to_scan_agg(
             if let AExpr::Agg(agg) = expr_arena.get(expr) {
                 match agg {
                     AAggExpr::Min(e) => ScanAggregation::Min {
-                        column: (*aexpr_to_root_names(*e, expr_arena).pop().unwrap()).to_string(),
+                        column: (*aexpr_to_leaf_names(*e, expr_arena).pop().unwrap()).to_string(),
                         alias,
                     },
                     AAggExpr::Max(e) => ScanAggregation::Max {
-                        column: (*aexpr_to_root_names(*e, expr_arena).pop().unwrap()).to_string(),
+                        column: (*aexpr_to_leaf_names(*e, expr_arena).pop().unwrap()).to_string(),
                         alias,
                     },
                     AAggExpr::Sum(e) => ScanAggregation::Sum {
-                        column: (*aexpr_to_root_names(*e, expr_arena).pop().unwrap()).to_string(),
+                        column: (*aexpr_to_leaf_names(*e, expr_arena).pop().unwrap()).to_string(),
                         alias,
                     },
                     AAggExpr::First(e) => ScanAggregation::First {
-                        column: (*aexpr_to_root_names(*e, expr_arena).pop().unwrap()).to_string(),
+                        column: (*aexpr_to_leaf_names(*e, expr_arena).pop().unwrap()).to_string(),
                         alias,
                     },
                     AAggExpr::Last(e) => ScanAggregation::Last {
-                        column: (*aexpr_to_root_names(*e, expr_arena).pop().unwrap()).to_string(),
+                        column: (*aexpr_to_leaf_names(*e, expr_arena).pop().unwrap()).to_string(),
                         alias,
                     },
                     _ => todo!(),
@@ -57,7 +57,7 @@ impl PhysicalPlanner {
         exprs: &[Node],
         context: Context,
         expr_arena: &mut Arena<AExpr>,
-    ) -> Result<Vec<Arc<dyn PhysicalExpr>>> {
+    ) -> PolarsResult<Vec<Arc<dyn PhysicalExpr>>> {
         exprs
             .iter()
             .map(|e| self.create_physical_expr(*e, context, expr_arena))
@@ -68,7 +68,7 @@ impl PhysicalPlanner {
         root: Node,
         lp_arena: &mut Arena<ALogicalPlan>,
         expr_arena: &mut Arena<AExpr>,
-    ) -> Result<Box<dyn Executor>> {
+    ) -> PolarsResult<Box<dyn Executor>> {
         use ALogicalPlan::*;
         let logical_plan = lp_arena.take(root);
         match logical_plan {
@@ -78,7 +78,7 @@ impl PhysicalPlanner {
                 let inputs = inputs
                     .into_iter()
                     .map(|node| self.create_physical_plan(node, lp_arena, expr_arena))
-                    .collect::<Result<Vec<_>>>()?;
+                    .collect::<PolarsResult<Vec<_>>>()?;
                 Ok(Box::new(executors::UnionExec { inputs, options }))
             }
             Melt { input, args, .. } => {
@@ -204,27 +204,13 @@ impl PhysicalPlanner {
                 selection,
                 ..
             } => {
-                let has_windows = if let Some(projection) = &projection {
-                    projection
-                        .iter()
-                        .any(|node| has_aexpr_window(*node, expr_arena))
-                } else {
-                    false
-                };
-
                 let selection = selection
                     .map(|pred| self.create_physical_expr(pred, Context::Default, expr_arena))
                     .map_or(Ok(None), |v| v.map(Some))?;
-                let projection = projection
-                    .map(|proj| {
-                        self.create_physical_expressions(&proj, Context::Default, expr_arena)
-                    })
-                    .map_or(Ok(None), |v| v.map(Some))?;
                 Ok(Box::new(executors::DataFrameExec {
                     df,
                     projection,
                     selection,
-                    has_windows,
                 }))
             }
             AnonymousScan {
@@ -260,9 +246,9 @@ impl PhysicalPlanner {
                 let input = self.create_physical_plan(input, lp_arena, expr_arena)?;
                 Ok(Box::new(executors::ExplodeExec { input, columns }))
             }
-            Cache { input, id } => {
+            Cache { input, id, count } => {
                 let input = self.create_physical_plan(input, lp_arena, expr_arena)?;
-                Ok(Box::new(executors::CacheExec { id, input }))
+                Ok(Box::new(executors::CacheExec { id, input, count }))
             }
             Distinct { input, options } => {
                 let input = self.create_physical_plan(input, lp_arena, expr_arena)?;
@@ -413,7 +399,7 @@ impl PhysicalPlanner {
 
                             #[cfg(feature = "object")]
                             {
-                                for name in aexpr_to_root_names(*agg, expr_arena) {
+                                for name in aexpr_to_leaf_names(*agg, expr_arena) {
                                     let dtype = input_schema.get(&name).unwrap();
 
                                     if let DataType::Object(_) = dtype {
@@ -464,10 +450,10 @@ impl PhysicalPlanner {
                 } else if options.allow_parallel {
                     // check if two DataFrames come from a separate source.
                     // If they don't we can parallelize,
-                    // Otherwise it is in cache.
-                    let mut sources_left = PlHashSet::with_capacity(16);
+                    // we may deadlock if we don't check this
+                    let mut sources_left = PlHashSet::new();
                     agg_source_paths(input_left, &mut sources_left, lp_arena);
-                    let mut sources_right = PlHashSet::with_capacity(16);
+                    let mut sources_right = PlHashSet::new();
                     agg_source_paths(input_right, &mut sources_right, lp_arena);
                     sources_left.intersection(&sources_right).next().is_none()
                 } else {
@@ -517,7 +503,7 @@ impl PhysicalPlanner {
                 let contexts = contexts
                     .into_iter()
                     .map(|node| self.create_physical_plan(node, lp_arena, expr_arena))
-                    .collect::<Result<_>>()?;
+                    .collect::<PolarsResult<_>>()?;
                 Ok(Box::new(executors::ExternalContext { input, contexts }))
             }
         }
