@@ -11,7 +11,7 @@
 //!
 //! ```rust no_run
 //! use polars::prelude::*;
-//! # fn example() -> Result<()> {
+//! # fn example() -> PolarsResult<()> {
 //!
 //! let lf1 = LazyFrame::scan_parquet("myfile_1.parquet", Default::default())?
 //!     .groupby([col("ham")])
@@ -31,7 +31,7 @@
 //!     .select([col("ham"), col("spam")]);
 //!
 //! let df = lf1
-//!     .join(lf2, [col("reverse_group")], [col("foo")], JoinType::Left)
+//!     .join(lf2, [col("reverse")], [col("foo")], JoinType::Left)
 //!     // now we finally materialize the result.
 //!     .collect()?;
 //! # Ok(())
@@ -118,7 +118,7 @@
 //!
 //! ```no_run
 //! # use polars::prelude::*;
-//! # fn example() -> Result<()> {
+//! # fn example() -> PolarsResult<()> {
 //! # let df = DataFrame::default();
 //!   df.lazy()
 //!    .select([
@@ -183,6 +183,7 @@
 //!                  This allows polars to scale up way beyond that by using `u64` as an index.
 //!                  Polars will be a bit slower with this feature activated as many data structures
 //!                  are less cache efficient.
+//!     - `cse` - Activate common subplan elimination optimization
 //! * IO related:
 //!     - `serde` - Support for [serde](https://crates.io/crates/serde) serialization and deserialization.
 //!                 Can be used for JSON and more serde supported serialization formats.
@@ -342,11 +343,12 @@ pub mod docs;
 pub mod export;
 pub mod prelude;
 
-pub use polars_core::apply_method_all_arrow_series;
-pub use polars_core::df;
+pub use polars_core::{
+    apply_method_all_arrow_series, chunked_array, datatypes, df, doc, error, frame, functions,
+    series, testing,
+};
 #[cfg(feature = "dtype-categorical")]
-pub use polars_core::toggle_string_cache;
-pub use polars_core::{chunked_array, datatypes, doc, error, frame, functions, series, testing};
+pub use polars_core::{toggle_string_cache, using_string_cache};
 #[cfg(feature = "polars-io")]
 pub use polars_io as io;
 #[cfg(feature = "lazy")]
