@@ -3,7 +3,14 @@ from __future__ import annotations
 from typing import TYPE_CHECKING
 
 import polars.internals as pli
-from polars.datatypes import DataType, Date, Datetime, Time, is_polars_dtype
+from polars.datatypes import (
+    DataType,
+    Date,
+    Datetime,
+    TemporalDataType,
+    Time,
+    is_polars_dtype,
+)
 from polars.utils import deprecated_alias
 
 if TYPE_CHECKING:
@@ -20,7 +27,7 @@ class ExprStringNameSpace:
 
     def strptime(
         self,
-        datatype: type[Date] | type[Datetime] | type[Time],
+        datatype: TemporalDataType,
         fmt: str | None = None,
         strict: bool = True,
         exact: bool = True,
@@ -31,7 +38,7 @@ class ExprStringNameSpace:
         Parameters
         ----------
         datatype
-            Date | Datetime | Time.
+            Date | Datetime | Time
         fmt
             Format to use, refer to the `chrono strftime documentation
             <https://docs.rs/chrono/latest/chrono/format/strftime/index.html>`_
@@ -42,6 +49,12 @@ class ExprStringNameSpace:
             - If True, require an exact format match.
             - If False, allow the format to match anywhere in the target string.
 
+        Notes
+        -----
+        When parsing a Datetime the column precision will be inferred from
+        the format string, if given, eg: "%F %T%.3f" => Datetime("ms"). If
+        no fractional second component is found then the default is "us".
+
         Examples
         --------
         Dealing with different formats.
@@ -88,7 +101,9 @@ class ExprStringNameSpace:
         if datatype == Date:
             return pli.wrap_expr(self._pyexpr.str_parse_date(fmt, strict, exact))
         elif datatype == Datetime:
-            return pli.wrap_expr(self._pyexpr.str_parse_datetime(fmt, strict, exact))
+            tu = datatype.tu  # type: ignore[union-attr]
+            dtcol = pli.wrap_expr(self._pyexpr.str_parse_datetime(fmt, strict, exact))
+            return dtcol if (tu is None) else dtcol.dt.cast_time_unit(tu)
         elif datatype == Time:
             return pli.wrap_expr(self._pyexpr.str_parse_time(fmt, strict, exact))
         else:  # pragma: no cover
@@ -265,6 +280,8 @@ class ExprStringNameSpace:
 
     def zfill(self, alignment: int) -> pli.Expr:
         """
+        Fills the string with zeroes.
+
         Return a copy of the string left filled with ASCII '0' digits to make a string
         of length width.
 
@@ -530,6 +547,7 @@ class ExprStringNameSpace:
     def json_path_match(self, json_path: str) -> pli.Expr:
         """
         Extract the first match of json string with provided JSONPath expression.
+
         Throw errors if encounter invalid json strings.
         All return value will be casted to Utf8 regardless of the original value.
 
@@ -704,7 +722,9 @@ class ExprStringNameSpace:
 
     def extract_all(self, pattern: str) -> pli.Expr:
         r"""
-        Extract each successive non-overlapping regex match in an individual string as
+        Extracts all matches for the given regex pattern.
+
+        Extracts each successive non-overlapping regex match in an individual string as
         an array.
 
         Parameters
@@ -813,8 +833,9 @@ class ExprStringNameSpace:
 
     def split_exact(self, by: str, n: int, inclusive: bool = False) -> pli.Expr:
         """
-        Split the string by a substring into a struct of ``n+1`` fields using
-        ``n`` splits.
+        Split the string by a substring using ``n`` splits.
+
+        Results in a struct of ``n+1`` fields.
 
         If it cannot make ``n`` splits, the remaining field elements will be null.
 
