@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import sys
-from datetime import date, datetime, timedelta
+from datetime import date, datetime, time, timedelta
 from inspect import isclass
 from typing import TYPE_CHECKING, Any, Callable, Sequence, cast, overload
 
@@ -12,11 +12,16 @@ from polars.datatypes import (
     Datetime,
     Duration,
     PolarsDataType,
+    Time,
     UInt32,
     is_polars_dtype,
     py_type_to_dtype,
 )
-from polars.utils import _datetime_to_pl_timestamp, _timedelta_to_pl_timedelta
+from polars.utils import (
+    _datetime_to_pl_timestamp,
+    _time_to_pl_time,
+    _timedelta_to_pl_timedelta,
+)
 
 try:
     from polars.polars import arange as pyarange
@@ -65,7 +70,7 @@ if TYPE_CHECKING:
 
 
 def col(
-    name: str | list[str] | Sequence[PolarsDataType] | pli.Series | PolarsDataType,
+    name: str | Sequence[str] | Sequence[PolarsDataType] | pli.Series | PolarsDataType,
 ) -> pli.Expr:
     """
     Return an expression representing a column in a DataFrame.
@@ -169,7 +174,7 @@ def col(
     if isinstance(name, DataType):
         return pli.wrap_expr(_dtype_cols([name]))
 
-    if isinstance(name, list):
+    elif not isinstance(name, str) and isinstance(name, Sequence):
         if len(name) == 0 or isinstance(name[0], str):
             return pli.wrap_expr(pycols(name))
         elif is_polars_dtype(name[0]):
@@ -309,7 +314,7 @@ def var(column: str | pli.Series, ddof: int = 1) -> pli.Expr | float | None:
 
 
 @overload
-def max(column: str | list[pli.Expr | str]) -> pli.Expr:
+def max(column: str | Sequence[pli.Expr | str]) -> pli.Expr:
     ...
 
 
@@ -318,7 +323,7 @@ def max(column: pli.Series) -> int | float:
     ...
 
 
-def max(column: str | list[pli.Expr | str] | pli.Series) -> pli.Expr | Any:
+def max(column: str | Sequence[pli.Expr | str] | pli.Series) -> pli.Expr | Any:
     """
     Get the maximum value. Can be used horizontally or vertically.
 
@@ -333,15 +338,15 @@ def max(column: str | list[pli.Expr | str] | pli.Series) -> pli.Expr | Any:
     """
     if isinstance(column, pli.Series):
         return column.max()
-    elif isinstance(column, list):
+    elif isinstance(column, str):
+        return col(column).max()
+    else:
         exprs = pli.selection_to_pyexpr_list(column)
         return pli.wrap_expr(_max_exprs(exprs))
-    else:
-        return col(column).max()
 
 
 @overload
-def min(column: str | list[pli.Expr | str]) -> pli.Expr:
+def min(column: str | Sequence[pli.Expr | str]) -> pli.Expr:
     ...
 
 
@@ -350,7 +355,7 @@ def min(column: pli.Series) -> int | float:
     ...
 
 
-def min(column: str | list[pli.Expr | str] | pli.Series) -> pli.Expr | Any:
+def min(column: str | Sequence[pli.Expr | str] | pli.Series) -> pli.Expr | Any:
     """
     Get the minimum value.
 
@@ -363,15 +368,15 @@ def min(column: str | list[pli.Expr | str] | pli.Series) -> pli.Expr | Any:
     """
     if isinstance(column, pli.Series):
         return column.min()
-    elif isinstance(column, list):
+    elif isinstance(column, str):
+        return col(column).min()
+    else:
         exprs = pli.selection_to_pyexpr_list(column)
         return pli.wrap_expr(_min_exprs(exprs))
-    else:
-        return col(column).min()
 
 
 @overload
-def sum(column: str | list[pli.Expr | str] | pli.Expr) -> pli.Expr:
+def sum(column: str | Sequence[pli.Expr | str] | pli.Expr) -> pli.Expr:
     ...
 
 
@@ -380,7 +385,9 @@ def sum(column: pli.Series) -> int | float:
     ...
 
 
-def sum(column: str | list[pli.Expr | str] | pli.Series | pli.Expr) -> pli.Expr | Any:
+def sum(
+    column: str | Sequence[pli.Expr | str] | pli.Series | pli.Expr,
+) -> pli.Expr | Any:
     """
     Sum values in a column/Series, or horizontally across list of columns/expressions.
 
@@ -469,14 +476,14 @@ def sum(column: str | list[pli.Expr | str] | pli.Series | pli.Expr) -> pli.Expr
     """
     if isinstance(column, pli.Series):
         return column.sum()
-    elif isinstance(column, list):
+    elif isinstance(column, str):
+        return col(column).sum()
+    elif isinstance(column, Sequence):
         exprs = pli.selection_to_pyexpr_list(column)
         return pli.wrap_expr(_sum_exprs(exprs))
-    elif isinstance(column, pli.Expr):
-        # use u32 as that is not cast to float as eagerly
-        return fold(lit(0).cast(UInt32), lambda a, b: a + b, column).alias("sum")
     else:
-        return col(column).sum()
+        # (Expr): use u32 as that will not cast to float as eagerly
+        return fold(lit(0).cast(UInt32), lambda a, b: a + b, column).alias("sum")
 
 
 @overload
@@ -725,6 +732,9 @@ def lit(
         tu = "us"
         return lit(_timedelta_to_pl_timedelta(value, tu)).cast(Duration(tu))
 
+    elif isinstance(value, time):
+        return lit(_time_to_pl_time(value)).cast(Time)
+
     elif isinstance(value, date):
         return lit(datetime(value.year, value.month, value.day)).cast(Date)
 
@@ -830,8 +840,8 @@ def cov(
 
 
 def map(
-    exprs: list[str] | list[pli.Expr],
-    f: Callable[[list[pli.Series]], pli.Series],
+    exprs: Sequence[str] | Sequence[pli.Expr],
+    f: Callable[[Sequence[pli.Series]], pli.Series],
     return_dtype: type[DataType] | None = None,
 ) -> pli.Expr:
     """
@@ -858,8 +868,8 @@ def map(
 
 
 def apply(
-    exprs: list[str | pli.Expr],
-    f: Callable[[list[pli.Series]], pli.Series | Any],
+    exprs: Sequence[str | pli.Expr],
+    f: Callable[[Sequence[pli.Series]], pli.Series | Any],
     return_dtype: type[DataType] | None = None,
 ) -> pli.Expr:
     """
@@ -920,19 +930,20 @@ def fold(
     return pli.wrap_expr(pyfold(acc._pyexpr, f, exprs))
 
 
-def any(name: str | list[str] | list[pli.Expr] | pli.Expr) -> pli.Expr:
+def any(name: str | Sequence[str] | Sequence[pli.Expr] | pli.Expr) -> pli.Expr:
     """Evaluate columnwise or elementwise with a bitwise OR operation."""
-    if isinstance(name, (list, pli.Expr)):
+    if isinstance(name, str):
+        return col(name).any()
+    else:
         return fold(lit(False), lambda a, b: a.cast(bool) | b.cast(bool), name).alias(
             "any"
         )
-    return col(name).any()
 
 
 def exclude(
     columns: (
         str
-        | list[str]
+        | Sequence[str]
         | DataType
         | type[DataType]
         | DataType
@@ -1031,7 +1042,7 @@ def exclude(
     return col("*").exclude(columns)
 
 
-def all(name: str | list[pli.Expr] | pli.Expr | None = None) -> pli.Expr:
+def all(name: str | Sequence[pli.Expr] | pli.Expr | None = None) -> pli.Expr:
     """
     Do one of two things.
 
@@ -1063,11 +1074,12 @@ def all(name: str | list[pli.Expr] | pli.Expr | None = None) -> pli.Expr:
     """
     if name is None:
         return col("*")
-    if isinstance(name, (list, pli.Expr)):
+    elif isinstance(name, str):
+        return col(name).all()
+    else:
         return fold(lit(True), lambda a, b: a.cast(bool) & b.cast(bool), name).alias(
             "all"
         )
-    return col(name).all()
 
 
 def groups(column: str) -> pli.Expr:
@@ -1169,7 +1181,7 @@ def arange(
 
 def argsort_by(
     exprs: pli.Expr | str | Sequence[pli.Expr | str],
-    reverse: list[bool] | bool = False,
+    reverse: Sequence[bool] | bool = False,
 ) -> pli.Expr:
     """
     Find the indexes that would sort the columns.
@@ -1507,14 +1519,15 @@ def concat_list(exprs: Sequence[str | pli.Expr | pli.Series] | pli.Expr) -> pli.
 
 
 def collect_all(
-    lazy_frames: list[pli.LazyFrame],
+    lazy_frames: Sequence[pli.LazyFrame],
     type_coercion: bool = True,
     predicate_pushdown: bool = True,
     projection_pushdown: bool = True,
     simplify_expression: bool = True,
     string_cache: bool = False,
     no_optimization: bool = False,
-    slice_pushdown: bool = False,
+    slice_pushdown: bool = True,
+    common_subplan_elimination: bool = True,
 ) -> list[pli.DataFrame]:
     """
     Collect multiple LazyFrames at the same time.
@@ -1534,16 +1547,13 @@ def collect_all(
     simplify_expression
         Run simplify expressions optimization.
     string_cache
-        Use a global string cache in this query.
-        This is needed if you want to join on categorical columns.
-
-        Caution!
-            If you already have set a global string cache, set this to `False` as this
-            will reset the global cache when the query is finished.
+        This argument is deprecated and will be ignored
     no_optimization
         Turn off optimizations.
     slice_pushdown
         Slice pushdown optimization.
+    common_subplan_elimination
+        Will try to cache branching subplans that occur on self-joins or unions.
 
     Returns
     -------
@@ -1554,6 +1564,7 @@ def collect_all(
         predicate_pushdown = False
         projection_pushdown = False
         slice_pushdown = False
+        common_subplan_elimination = False
 
     prepared = []
 
@@ -1563,8 +1574,8 @@ def collect_all(
             predicate_pushdown,
             projection_pushdown,
             simplify_expression,
-            string_cache,
             slice_pushdown,
+            common_subplan_elimination,
         )
         prepared.append(ldf)
 
