@@ -10,7 +10,7 @@ from pathlib import Path
 from typing import TYPE_CHECKING, Callable, Iterable, Sequence, TypeVar
 
 import polars.internals as pli
-from polars.datatypes import DataType, Date, Datetime
+from polars.datatypes import DataType, Date, Datetime, PolarsDataType, is_polars_dtype
 
 try:
     from polars.polars import PyExpr
@@ -25,6 +25,19 @@ if sys.version_info >= (3, 10):
 else:
     from typing_extensions import ParamSpec, TypeGuard
 
+
+if sys.version_info >= (3, 9):
+    import zoneinfo
+
+    _ZONEINFO_AVAILABLE = True
+else:
+    try:
+        from backports import zoneinfo
+
+        _ZONEINFO_AVAILABLE = True
+    except ImportError:
+        _ZONEINFO_AVAILABLE = False
+
 if TYPE_CHECKING:
     from polars.internals.type_aliases import SizeUnit, TimeUnit
 
@@ -57,6 +70,11 @@ def _datetime_to_pl_timestamp(dt: datetime, tu: TimeUnit | None) -> int:
         raise ValueError(f"tu must be one of {{'ns', 'us', 'ms'}}, got {tu}")
 
 
+def _time_to_pl_time(t: time) -> int:
+    t = t.replace(tzinfo=timezone.utc)
+    return int((t.hour * 3_600 + t.minute * 60 + t.second) * 1e9 + t.microsecond * 1e3)
+
+
 def _timedelta_to_pl_timedelta(td: timedelta, tu: TimeUnit | None = None) -> int:
     if tu == "ns":
         return int(td.total_seconds() * 1e9)
@@ -76,41 +94,34 @@ def _date_to_pl_date(d: date) -> int:
     return int(dt.timestamp()) // (3600 * 24)
 
 
-def _is_iterable_of(val: Iterable[object], eltype: type) -> bool:
-    """Check whether the given iterable is of a certain type."""
+def _is_iterable_of(val: Iterable[object], eltype: type | tuple[type, ...]) -> bool:
+    """Check whether the given iterable is of the given type(s)."""
     return all(isinstance(x, eltype) for x in val)
 
 
 def is_bool_sequence(val: object) -> TypeGuard[Sequence[bool]]:
     """Check whether the given sequence is a sequence of booleans."""
-    if isinstance(val, Sequence):
-        return _is_iterable_of(val, bool)
-    else:
-        return False
+    return isinstance(val, Sequence) and _is_iterable_of(val, bool)
+
+
+def is_dtype_sequence(val: object) -> TypeGuard[Sequence[PolarsDataType]]:
+    """Check whether the given object is a sequence of polars DataTypes."""
+    return isinstance(val, Sequence) and all(is_polars_dtype(x) for x in val)
 
 
 def is_int_sequence(val: object) -> TypeGuard[Sequence[int]]:
     """Check whether the given sequence is a sequence of integers."""
-    if isinstance(val, Sequence):
-        return _is_iterable_of(val, int)
-    else:
-        return False
+    return isinstance(val, Sequence) and _is_iterable_of(val, int)
 
 
 def is_expr_sequence(val: object) -> TypeGuard[Sequence[pli.Expr]]:
     """Check whether the given object is a sequence of Exprs."""
-    if isinstance(val, Sequence):
-        return _is_iterable_of(val, pli.Expr)
-    else:
-        return False
+    return isinstance(val, Sequence) and _is_iterable_of(val, pli.Expr)
 
 
 def is_pyexpr_sequence(val: object) -> TypeGuard[Sequence[PyExpr]]:
     """Check whether the given object is a sequence of PyExprs."""
-    if isinstance(val, Sequence):
-        return _is_iterable_of(val, PyExpr)
-    else:
-        return False
+    return isinstance(val, Sequence) and _is_iterable_of(val, PyExpr)
 
 
 def is_str_sequence(
@@ -124,10 +135,7 @@ def is_str_sequence(
     """
     if allow_str is False and isinstance(val, str):
         return False
-    if isinstance(val, Sequence):
-        return _is_iterable_of(val, str)
-    else:
-        return False
+    return isinstance(val, Sequence) and _is_iterable_of(val, str)
 
 
 def range_to_slice(rng: range) -> slice:
@@ -214,19 +222,22 @@ def _to_python_datetime(
         else:
             raise ValueError(f"tu must be one of {{'ns', 'us', 'ms'}}, got {tu}")
         if tz is not None and len(tz) > 0:
-            try:
-                import pytz
-            except ImportError:
-                raise ImportError(
-                    "pytz is not installed. Please run `pip install pytz`."
-                ) from None
-
-            return pytz.timezone(tz).localize(dt)
+            return _localize(dt, tz)
         return dt
     else:
         raise NotImplementedError  # pragma: no cover
 
 
+def _localize(dt: datetime, tz: str) -> datetime:
+    if not _ZONEINFO_AVAILABLE:
+        raise ImportError(
+            "backports.zoneinfo is not installed. Please run "
+            "`pip install backports.zoneinfo`."
+        )
+
+    return dt.astimezone(zoneinfo.ZoneInfo(tz))
+
+
 def _in_notebook() -> bool:
     try:
         from IPython import get_ipython
