@@ -67,7 +67,7 @@ pub(crate) fn call_lambda_with_series(
 }
 
 /// A python lambda taking two Series
-pub(crate) fn binary_lambda(lambda: &PyObject, a: Series, b: Series) -> Result<Series> {
+pub(crate) fn binary_lambda(lambda: &PyObject, a: Series, b: Series) -> PolarsResult<Series> {
     Python::with_gil(|py| {
         // get the pypolars module
         let pypolars = PyModule::import(py, "polars").unwrap();
@@ -127,7 +127,7 @@ pub fn map_single(
     let output_type2 = output_type.clone();
     let function = move |s: Series| {
         Python::with_gil(|py| {
-            let output_type = output_type2.clone().unwrap_or_else(|| DataType::Unknown);
+            let output_type = output_type2.clone().unwrap_or(DataType::Unknown);
 
             // this is a python Series
             let out = call_lambda_with_series(py, s.clone(), &lambda, &POLARS)
