@@ -773,6 +773,7 @@ impl PySeries {
         &self,
         lambda: &PyAny,
         output_type: Option<Wrap<DataType>>,
+        skip_nulls: bool,
     ) -> PyResult<PySeries> {
         Python::with_gil(|py| {
             let series = &self.series;
@@ -786,7 +787,8 @@ impl PySeries {
                     | DataType::Duration(_)
                     | DataType::Categorical(_)
                     | DataType::Time
-            ) {
+            ) || !skip_nulls
+            {
                 let mut avs = Vec::with_capacity(self.series.len());
                 let iter = self.series.iter().map(|av| {
                     let input = Wrap(av);
@@ -1082,12 +1084,6 @@ impl PySeries {
         }
     }
 
-    pub fn with_time_zone(&self, tz: Option<TimeZone>) -> PyResult<Self> {
-        let mut dt = self.series.datetime().map_err(PyPolarsErr::from)?.clone();
-        dt.set_time_zone(tz);
-        Ok(dt.into_series().into())
-    }
-
     pub fn set_at_idx(&mut self, idx: PySeries, values: PySeries) -> PyResult<()> {
         // we take the value because we want a ref count
         // of 1 so that we can have mutable access
@@ -1162,7 +1158,11 @@ impl_ufuncs!(apply_ufunc_i64, Int64Type, unsafe_from_ptr_i64);
 
 macro_rules! impl_set_with_mask {
     ($name:ident, $native:ty, $cast:ident, $variant:ident) => {
-        fn $name(series: &Series, filter: &PySeries, value: Option<$native>) -> Result<Series> {
+        fn $name(
+            series: &Series,
+            filter: &PySeries,
+            value: Option<$native>,
+        ) -> PolarsResult<Series> {
             let mask = filter.series.bool()?;
             let ca = series.$cast()?;
             let new = ca.set(mask, value)?;
