@@ -4,6 +4,7 @@ from datetime import datetime
 from typing import TYPE_CHECKING
 
 import numpy as np
+import pandas as pd
 import pytest
 
 import polars as pl
@@ -418,3 +419,64 @@ def test_join_inline_alias_4694() -> None:
             datetime(2021, 2, 6, 0, 0),
         ],
     }
+
+
+def test_sorted_flag_after_joins() -> None:
+    np.random.seed(1)
+    dfa = pl.DataFrame(
+        {
+            "a": np.random.randint(0, 13, 20),
+            "b": np.random.randint(0, 13, 20),
+        }
+    ).sort("a")
+
+    dfb = pl.DataFrame(
+        {
+            "a": np.random.randint(0, 13, 10),
+            "b": np.random.randint(0, 13, 10),
+        }
+    )
+
+    dfapd = dfa.to_pandas()
+    dfbpd = dfb.to_pandas()
+
+    def test_with_pd(
+        dfa: pd.DataFrame, dfb: pd.DataFrame, on: str, how: str, joined: pl.DataFrame
+    ) -> None:
+        a = (
+            dfa.merge(
+                dfb,
+                on=on,
+                how=how,  # type: ignore[arg-type]
+                suffixes=("", "_right"),
+            )
+            .sort_values(["a", "b"])
+            .reset_index(drop=True)
+        )
+        b = joined.sort(["a", "b"]).to_pandas()
+        pd.testing.assert_frame_equal(a, b)
+
+    joined = dfa.join(dfb, on="b", how="left")
+    assert joined["a"].flags["SORTED_ASC"]
+    test_with_pd(dfapd, dfbpd, "b", "left", joined)
+
+    joined = dfa.join(dfb, on="b", how="inner")
+    assert joined["a"].flags["SORTED_ASC"]
+    test_with_pd(dfapd, dfbpd, "b", "inner", joined)
+
+    joined = dfa.join(dfb, on="b", how="semi")
+    assert joined["a"].flags["SORTED_ASC"]
+    joined = dfa.join(dfb, on="b", how="semi")
+    assert joined["a"].flags["SORTED_ASC"]
+
+    joined = dfb.join(dfa, on="b", how="left")
+    assert not joined["a"].flags["SORTED_ASC"]
+    test_with_pd(dfbpd, dfapd, "b", "left", joined)
+
+    joined = dfb.join(dfa, on="b", how="inner")
+    assert not joined["a"].flags["SORTED_ASC"]
+
+    joined = dfb.join(dfa, on="b", how="semi")
+    assert not joined["a"].flags["SORTED_ASC"]
+    joined = dfb.join(dfa, on="b", how="anti")
+    assert not joined["a"].flags["SORTED_ASC"]
